@@ -37,11 +37,31 @@
 #include "calendar_notes.h"
 #include "calendar_timeline.h"
 #include "calendar_calc.h"
+#include "calendar_ical.h"
 #include "time_utils.h"
 #include "date_utils.h"
 #include "calendar_moon.h"
 #include "stock_icons.h"
 
+/*------------------------------------------------------------------------------*/
+
+DATE*
+get_selected_date (GUI *appGUI) {
+
+DATE *c_date;
+
+    c_date = g_new0 (DATE, 1);
+
+    if (c_date != NULL) {
+        c_date->year = appGUI->cal->year;
+        c_date->month = appGUI->cal->month;
+        c_date->day = appGUI->cal->day;
+    }
+
+    return c_date;    
+}
+
+
 /*------------------------------------------------------------------------------*/
 
 void
@@ -239,16 +259,15 @@ gint i;
 
     while (gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path) == TRUE) {
         gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
-                            COLUMN_DUE_DATE_JULIAN, &date, COLUMN_DONE, &done, -1);
+                            TA_COLUMN_DUE_DATE_JULIAN, &date, TA_COLUMN_DONE, &done, -1);
 
         if (date == selected_julian) {
             if (count == FALSE) {
-                gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, COLUMN_SUMMARY, &summary, -1);
-                sprintf(tmpbuf, " %d. ", i+1);
-                gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, tmpbuf, -1);
-                gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, summary, -1);
+                gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, TA_COLUMN_SUMMARY, &summary, -1);
+                sprintf(tmpbuf, "%d. %s", i+1, summary);
                 if (done == TRUE) {
-                    sprintf(tmpbuf, " [ %s ]", _("Finished"));
+                    gtk_text_buffer_insert_with_tags_by_name (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, tmpbuf, -1, "strike", NULL);
+                } else {
                     gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, tmpbuf, -1);
                 }
                 gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n", -1);
@@ -307,9 +326,9 @@ gint i;
                                                 COLUMN_LAST_NAME, &last_name,
                                                 -1);
                             if (age == 0) {
-                                sprintf (tmpbuf, " %s %s %s\n", first_name, last_name, _("was born"));
+                                sprintf (tmpbuf, "%s %s %s\n", first_name, last_name, _("was born"));
                             } else {
-                                sprintf (tmpbuf, " %s %s (%d %s)\n", first_name, last_name, age,
+                                sprintf (tmpbuf, "%s %s (%d %s)\n", first_name, last_name, age,
                                     ngettext ("year old", "years old", age));
                             }
 
@@ -384,7 +403,7 @@ guint32 date, selected_julian;
 
         while (gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path) == TRUE) {
             gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
-                                COLUMN_DUE_DATE_JULIAN, &date, -1);
+                                TA_COLUMN_DUE_DATE_JULIAN, &date, -1);
 
             if (date == selected_julian) {
                 return TRUE;
@@ -427,7 +446,7 @@ guint32 date, age, selected_julian;
 
                     if (age >= 0) {
 
-                        g_date_set_year (new_cdate, appGUI->cal->year);
+                        g_date_set_year (new_cdate, tc_year);
                         date = g_date_get_julian (new_cdate);
 
                         if (date != 0 && selected_julian == date) {
@@ -476,182 +495,275 @@ gchar tmpbuf[BUFFER_SIZE];
 gint ydays, edays;
 gboolean current_date;
 static guint cmonth;
+gint i, rows;
+
+#ifdef HAVE_LIBICAL
+DATE *c_date;
+#endif  /* HAVE_LIBICAL */
 
     gui_clear_text_buffer (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter);
 
     ydays = get_day_of_the_year (dday, dmonth, dyear);
 
-    anchor = gtk_text_buffer_create_child_anchor (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter);
+    rows = config.di_show_current_time + config.di_show_day_number + config.di_show_marked_days + 
+           + config.di_show_week_number + config.di_show_weekend_days + config.di_show_moon_phase +
+           config.di_show_zodiac_sign;
 
-    table = gtk_table_new (6, 3, FALSE);
-    gtk_widget_show (table);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+    if (rows != 0) {
+        anchor = gtk_text_buffer_create_child_anchor (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter);
+
+        table = gtk_table_new (rows, 3, FALSE);
+        gtk_widget_show (table);
+        gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+        gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+    }
 
     current_date = (dday == get_current_day()) && (dmonth == get_current_month()) && (dyear == get_current_year());
 
-    if (current_date) {
+    i = 0;
+
+    if (current_date && config.di_show_current_time) {
         sprintf(tmpbuf, "<b>%s:</b>", _("Current time"));
         label = gtk_label_new (tmpbuf);
         gtk_widget_show (label);
-        gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        i++;
+    }
+
+    if (config.di_show_day_number) {
+        sprintf(tmpbuf, "<b>%s:</b>", _("Day number"));
+        label = gtk_label_new (tmpbuf);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        i++;
+    }
+
+    if (config.di_show_week_number) {
+        sprintf(tmpbuf, "<b>%s:</b>", _("Week number"));
+        label = gtk_label_new (tmpbuf);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        i++;
+    }
+
+    if (config.di_show_marked_days) {
+        sprintf(tmpbuf, "<b>%s:</b>", _("Marked days"));
+        label = gtk_label_new (tmpbuf);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        i++;
+    }
+
+    if (config.di_show_weekend_days) {
+        sprintf(tmpbuf, "<b>%s:</b>", _("Weekend days"));
+        label = gtk_label_new (tmpbuf);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        i++;
+    }
+
+    if (config.di_show_moon_phase) {
+        sprintf(tmpbuf, "<b>%s:</b>", _("Moon phase"));
+        label = gtk_label_new (tmpbuf);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        i++;
+    }
+
+    if (config.di_show_zodiac_sign) {
+        sprintf(tmpbuf, "<b>%s:</b>", _("Zodiac sign"));
+        label = gtk_label_new (tmpbuf);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
                           (GtkAttachOptions) (GTK_FILL),
                           (GtkAttachOptions) (0), 0, 0);
         gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
         gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     }
 
-    sprintf(tmpbuf, "<b>%s:</b>", _("Day number"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-
-    sprintf(tmpbuf, "<b>%s:</b>", _("Week number"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-
-    sprintf(tmpbuf, "<b>%s:</b>", _("Marked days"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-
-    sprintf(tmpbuf, "<b>%s:</b>", _("Weekend days"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-
-    sprintf(tmpbuf, "<b>%s:</b>", _("Moon phase"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    i = 0;
 
     appGUI->cal->time_label = gtk_label_new (NULL);
-    if (current_date) {
+    if (current_date && config.di_show_current_time) {
         time_handler (appGUI);
         gtk_widget_show (appGUI->cal->time_label);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->time_label, 1, 3, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->time_label), 0, 0.5);
+        i++;
     }
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->time_label, 1, 3, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->time_label), 0, 0.5);
 
-    appGUI->cal->day_number_label = gtk_label_new (NULL);
-    gtk_widget_show (appGUI->cal->day_number_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_label, 1, 2, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->day_number_label), 0, 0.5);
+    if (config.di_show_day_number) {
+        appGUI->cal->day_number_label = gtk_label_new (NULL);
+        gtk_widget_show (appGUI->cal->day_number_label);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_label, 1, 2, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->day_number_label), 0, 0.5);
 
-    appGUI->cal->day_number_year_label = gtk_label_new (NULL);
-    gtk_widget_show (appGUI->cal->day_number_year_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_year_label, 2, 3, 1, 2,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->day_number_year_label), 0, 0.5);
-
-    appGUI->cal->week_number_label = gtk_label_new (NULL);
-    gtk_widget_show (appGUI->cal->week_number_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->week_number_label, 1, 3, 3, 4,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->week_number_label), 0, 0.5);
-
-    appGUI->cal->marked_days_label = gtk_label_new (NULL);
-    gtk_widget_show (appGUI->cal->marked_days_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->marked_days_label, 1, 3, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->marked_days_label), 0, 0.5);
-
-    appGUI->cal->weekend_days_label = gtk_label_new (NULL);
-    gtk_widget_show (appGUI->cal->weekend_days_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->weekend_days_label, 1, 3, 4, 5,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->weekend_days_label), 0, 0.5);
-
-    appGUI->cal->moon_icon = gtk_image_new();
-    gtk_widget_show (appGUI->cal->moon_icon);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_icon, 1, 2, 5, 6,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->moon_icon), 0, 0.5);
-
-    appGUI->cal->moon_phase_label = gtk_label_new (NULL);
-    gtk_widget_show (appGUI->cal->moon_phase_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_phase_label, 2, 3, 5, 6,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->moon_phase_label), 0, 0.5);
-
-
-    sprintf(tmpbuf, "%d", ydays);
-    gtk_label_set_text (GTK_LABEL(appGUI->cal->day_number_label), tmpbuf);
-
-    edays = get_days_per_year(dyear)-ydays;
-    if (edays) {
-        sprintf(tmpbuf, "(%d %s)", edays,
-            ngettext ("day till end of year", "days till end of year", edays));
-    } else {
-        sprintf(tmpbuf, "(%s)", _("the last day of the year"));
+        appGUI->cal->day_number_year_label = gtk_label_new (NULL);
+        gtk_widget_show (appGUI->cal->day_number_year_label);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_year_label, 2, 3, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->day_number_year_label), 0, 0.5);
+        i++;
     }
-    gtk_label_set_text (GTK_LABEL(appGUI->cal->day_number_year_label), tmpbuf);
 
-    if (week_number (dyear, dmonth+1, dday) > weeks_in_year (dyear)) {
-        sprintf (tmpbuf, "1 / %d", weeks_in_year (dyear+1));
-    } else {
-        sprintf (tmpbuf, "%d / %d", week_number (dyear, dmonth+1, dday), weeks_in_year (dyear));
+    if (config.di_show_week_number) {
+        appGUI->cal->week_number_label = gtk_label_new (NULL);
+        gtk_widget_show (appGUI->cal->week_number_label);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->week_number_label, 1, 3, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->week_number_label), 0, 0.5);
+        i++;
     }
-    gtk_label_set_text (GTK_LABEL(appGUI->cal->week_number_label), tmpbuf);
 
-    set_moon_icon (calc_moon_phase(dyear, dmonth+1, dday), appGUI);
+    if (config.di_show_marked_days) {
+        appGUI->cal->marked_days_label = gtk_label_new (NULL);
+        gtk_widget_show (appGUI->cal->marked_days_label);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->marked_days_label, 1, 3, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->marked_days_label), 0, 0.5);
+        i++;
+    }
 
-    sprintf(tmpbuf, "%d", get_marked_days(dmonth, dyear, appGUI));
-    gtk_label_set_text (GTK_LABEL(appGUI->cal->marked_days_label), tmpbuf);
-    sprintf(tmpbuf, "%d", get_weekend_days(dmonth, dyear));
-    gtk_label_set_text (GTK_LABEL(appGUI->cal->weekend_days_label), tmpbuf);
+    if (config.di_show_weekend_days) {
+        appGUI->cal->weekend_days_label = gtk_label_new (NULL);
+        gtk_widget_show (appGUI->cal->weekend_days_label);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->weekend_days_label, 1, 3, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->weekend_days_label), 0, 0.5);
+        i++;
+    }
 
-    gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW(appGUI->cal->day_desc_textview), table, anchor);
-    gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n\n", -1);
+    if (config.di_show_moon_phase) {
+        appGUI->cal->moon_icon = gtk_image_new();
+        gtk_widget_show (appGUI->cal->moon_icon);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_icon, 1, 2, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->moon_icon), 0, 0.5);
 
-    if (config.notes_in_info_panel) {
+        appGUI->cal->moon_phase_label = gtk_label_new (NULL);
+        gtk_widget_show (appGUI->cal->moon_phase_label);
+        gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_phase_label, 2, 3, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (appGUI->cal->moon_phase_label), 0, 0.5);
+
+        set_moon_icon (calc_moon_phase(dyear, dmonth+1, dday), appGUI);
+        i++;
+    }
+
+    if (config.di_show_zodiac_sign) {
+        label = gtk_label_new (NULL);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 1, 3, i, i+1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        gtk_label_set_text (GTK_LABEL(label), get_zodiac_name (dday, dmonth+1));
+    }
+    
+    if (config.di_show_day_number) {
+        sprintf(tmpbuf, "%d", ydays);
+        gtk_label_set_text (GTK_LABEL(appGUI->cal->day_number_label), tmpbuf);
+
+        edays = get_days_per_year(dyear)-ydays;
+        if (edays) {
+            sprintf(tmpbuf, "(%d %s)", edays,
+                ngettext ("day till end of year", "days till end of year", edays));
+        } else {
+            sprintf(tmpbuf, "(%s)", _("the last day of the year"));
+        }
+        gtk_label_set_text (GTK_LABEL(appGUI->cal->day_number_year_label), tmpbuf);
+    }
+
+    if (config.di_show_week_number) {
+        if (week_number (dyear, dmonth+1, dday) > weeks_in_year (dyear)) {
+            sprintf (tmpbuf, "1 / %d", weeks_in_year (dyear+1));
+        } else {
+            sprintf (tmpbuf, "%d / %d", week_number (dyear, dmonth+1, dday), weeks_in_year (dyear));
+        }
+        gtk_label_set_text (GTK_LABEL(appGUI->cal->week_number_label), tmpbuf);
+    }
+
+    if (config.di_show_marked_days) {
+        sprintf(tmpbuf, "%d", get_marked_days(dmonth, dyear, appGUI));
+        gtk_label_set_text (GTK_LABEL(appGUI->cal->marked_days_label), tmpbuf);
+    }
+
+    if (config.di_show_weekend_days) {
+        sprintf(tmpbuf, "%d", get_weekend_days(dmonth+1, dyear));
+        gtk_label_set_text (GTK_LABEL(appGUI->cal->weekend_days_label), tmpbuf);
+    }
+
+    if (rows != 0) {
+        gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW(appGUI->cal->day_desc_textview), table, anchor);
+        gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n\n", -1);
+    }
+
+    if (config.di_show_notes) {
 
         text = get_note(dday, dmonth+1, dyear, appGUI);
 
         if (text != NULL) {
             sprintf(tmpbuf, "%s:\n", _("Day notes"));
             gtk_text_buffer_insert_with_tags_by_name (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, tmpbuf, -1, "bold", NULL);
-            gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, text, -1);
+
+            if (date_to_julian(dday, dmonth, dyear) < get_julian_for_today() && config.strikethrough_past_notes == TRUE) {
+                gtk_text_buffer_insert_with_tags_by_name (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, text, -1, "strike", NULL);
+            } else {
+                gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, text, -1);
+            }
+
             if (text[strlen(text)-1] != '\n') {
                 gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n\n", -1);
             } else {
                 gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n", -1);
             }
         }
+    
     }
 
     check_tasks_and_contacts(date_to_julian (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year), appGUI);
+    
+#ifdef HAVE_LIBICAL
+    c_date = get_selected_date (appGUI);
+    if (c_date != NULL) {
+        calendar_display_ics (c_date, appGUI);
+        g_free(c_date);
+    }
+#endif  /* HAVE_LIBICAL */
 
     if (cmonth != dmonth) {
         cmonth = dmonth;
@@ -850,6 +962,8 @@ guint max_day;
 void
 calendar_btn_prev_day (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date (GUI_CALENDAR(appGUI->cal->calendar), 
                            &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->day > 1) {
@@ -873,6 +987,8 @@ calendar_btn_prev_day (GUI *appGUI) {
 void 
 calendar_btn_next_day (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date (GUI_CALENDAR(appGUI->cal->calendar), 
                            &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->day < get_number_of_days_in_month(appGUI->cal->month, appGUI->cal->year)) {
@@ -895,6 +1011,7 @@ calendar_btn_next_day (GUI *appGUI) {
 
 void 
 calendar_btn_today (GUI *appGUI) {
+    calendar_store_note (appGUI);
     set_today (FALSE, appGUI);
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
@@ -904,6 +1021,8 @@ calendar_btn_today (GUI *appGUI) {
 void 
 calendar_btn_prev_week (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date (GUI_CALENDAR(appGUI->cal->calendar), 
                            &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->day > 7) {
@@ -927,6 +1046,8 @@ calendar_btn_prev_week (GUI *appGUI) {
 void 
 calendar_btn_next_week (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date (GUI_CALENDAR(appGUI->cal->calendar), 
                            &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->day <= get_number_of_days_in_month(appGUI->cal->month, appGUI->cal->year)-7) {
@@ -950,6 +1071,8 @@ calendar_btn_next_week (GUI *appGUI) {
 void 
 calendar_btn_prev_month (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date(GUI_CALENDAR(appGUI->cal->calendar), 
                           &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->month > 0) {
@@ -967,6 +1090,8 @@ calendar_btn_prev_month (GUI *appGUI) {
 void 
 calendar_btn_next_month (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date(GUI_CALENDAR(appGUI->cal->calendar), 
                           &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->month < 11) {
@@ -984,6 +1109,8 @@ calendar_btn_next_month (GUI *appGUI) {
 void 
 calendar_btn_prev_year (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date(GUI_CALENDAR(appGUI->cal->calendar), 
                           &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->year > JULIAN_GREGORIAN_YEAR) appGUI->cal->year--;
@@ -996,6 +1123,8 @@ calendar_btn_prev_year (GUI *appGUI) {
 void 
 calendar_btn_next_year (GUI *appGUI) {
 
+    calendar_store_note (appGUI);
+
     gui_calendar_get_date(GUI_CALENDAR(appGUI->cal->calendar), 
                           &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     appGUI->cal->year++;
@@ -1005,6 +1134,22 @@ calendar_btn_next_year (GUI *appGUI) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+calendar_store_note (GUI *appGUI) {
+
+gchar *text;
+
+    text = calendar_get_note_text(appGUI);
+
+    if (config.day_notes_visible && strlen(text)) {
+        add_note (appGUI->cal->day, appGUI->cal->month+1, appGUI->cal->year, 
+                  get_color(appGUI->cal->day, appGUI->cal->month+1, appGUI->cal->year, appGUI), 
+                  text, appGUI);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 calendar_day_selected_cb (GuiCalendar *calendar, gpointer user_data) {
 
@@ -1262,7 +1407,6 @@ GtkWidget       *vseparator;
 GtkUIManager    *uim_widget = NULL;
 GError          *error = NULL;
 GtkActionGroup  *action_group = NULL;
-GtkWidget       *i_scrolledwindow;
 GtkWidget       *note_scrolledwindow;
 GtkWidget       *calendars_table;
 
@@ -1306,17 +1450,18 @@ guint n_entries = G_N_ELEMENTS (entries);
 guint n_t_entries = G_N_ELEMENTS (t_entries);
 
 
-    label = gtk_label_new(NULL);
-    gtk_label_set_angle (GTK_LABEL(label), -90.0);
-    sprintf(tmpbuf, "<b>%s</b>", _("Calendar"));
-    gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
-
     vbox1 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox1);
     gtk_container_set_border_width (GTK_CONTAINER (vbox1), 8);
-    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox1, label);
+    sprintf(tmpbuf, "<b>%s</b>", _("Calendar"));
+    gui_add_to_notebook (vbox1, tmpbuf, appGUI);
+
     appGUI->cal->vbox = GTK_BOX(vbox1);
 
+    if (config.hide_calendar == TRUE) {
+        gtk_widget_hide(GTK_WIDGET(appGUI->cal->vbox));
+    }
+
     /*-------------------------------------------------------------------------------------*/
 
     action_group = gtk_action_group_new ("_actions");
@@ -1409,7 +1554,7 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
     gui_calendar_set_cursor_type(GUI_CALENDAR(appGUI->cal->calendar), config.cursor_type);
     GTK_WIDGET_UNSET_FLAGS(appGUI->cal->calendar, GTK_CAN_FOCUS);
     gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar), config.display_options);
-    gtk_widget_modify_font (GTK_WIDGET(appGUI->cal->calendar), appGUI->fd_calendar);
+    gtk_widget_modify_font (GTK_WIDGET(appGUI->cal->calendar), appGUI->fd_calendar_cal);
     gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->calendar, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (appGUI->cal->calendar), "day-selected", 
                       G_CALLBACK (calendar_day_selected_cb), appGUI);
@@ -1483,10 +1628,6 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         gui_calendar_set_weekend_color(GUI_CALENDAR (appGUI->cal->calendar_next), config.weekend_color);
         gui_calendar_set_mark_symbol (GUI_CALENDAR (appGUI->cal->calendar_next), get_mark_symbol(config.mark_symbol));
 
-    /*-------------------------------------------------------------------------------------*/
-
-    /*if (appGUI->calendar_only == FALSE) {*/
-
     /*-------------------------------------------------------------------------------------*/
     /* notes */
 
@@ -1563,7 +1704,7 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         gtk_container_add (GTK_CONTAINER (note_scrolledwindow), appGUI->cal->calendar_note_textview);
         gtk_text_view_set_accepts_tab (GTK_TEXT_VIEW (appGUI->cal->calendar_note_textview), TRUE);
         gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (appGUI->cal->calendar_note_textview), GTK_WRAP_WORD);
-        gtk_widget_modify_font (GTK_WIDGET(appGUI->cal->calendar_note_textview), appGUI->fd_notes);
+        gtk_widget_modify_font (GTK_WIDGET(appGUI->cal->calendar_note_textview), appGUI->fd_calendar_notes);
         gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview), 4);
         gtk_text_view_set_left_margin(GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview), 4);
         gtk_text_view_set_right_margin(GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview), 4);
@@ -1592,11 +1733,11 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         gtk_frame_set_label_widget (GTK_FRAME (frame), label);
         gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-        i_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-        gtk_widget_show (i_scrolledwindow);
-        gtk_container_add (GTK_CONTAINER (alignment), i_scrolledwindow);
-        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (i_scrolledwindow), GTK_SHADOW_NONE);
-        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (i_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+        appGUI->cal->day_info_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+        gtk_widget_show (appGUI->cal->day_info_scrolledwindow);
+        gtk_container_add (GTK_CONTAINER (alignment), appGUI->cal->day_info_scrolledwindow);
+        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (appGUI->cal->day_info_scrolledwindow), GTK_SHADOW_NONE);
+        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->cal->day_info_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
         appGUI->cal->day_desc_textview = gtk_text_view_new ();
         gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (appGUI->cal->day_desc_textview), GTK_WRAP_WORD);
@@ -1606,21 +1747,21 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(appGUI->cal->day_desc_textview), FALSE);
         gtk_text_view_set_editable(GTK_TEXT_VIEW(appGUI->cal->day_desc_textview), FALSE);
         gtk_widget_show (appGUI->cal->day_desc_textview);
-        gtk_container_add (GTK_CONTAINER (i_scrolledwindow), appGUI->cal->day_desc_textview);
+        gtk_container_add (GTK_CONTAINER (appGUI->cal->day_info_scrolledwindow), appGUI->cal->day_desc_textview);
         gtk_widget_realize(appGUI->cal->day_desc_textview);
         gtk_widget_modify_base (appGUI->cal->day_desc_textview, GTK_STATE_NORMAL, &appGUI->main_window->style->bg[GTK_STATE_NORMAL]);
 
         appGUI->cal->day_desc_text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cal->day_desc_textview));
         gtk_text_buffer_create_tag (appGUI->cal->day_desc_text_buffer, "bold", "weight", PANGO_WEIGHT_ULTRABOLD, NULL);
+        gtk_text_buffer_create_tag (appGUI->cal->day_desc_text_buffer, "strike", "strikethrough", TRUE, NULL);
 
     /*-------------------------------------------------------------------------------------*/
 
     }
 
-    gtk_widget_modify_font (GTK_WIDGET(appGUI->cal->date_label), appGUI->fd_day_name);
+    gtk_widget_modify_font (GTK_WIDGET(appGUI->cal->date_label), appGUI->fd_calendar_day_name);
     gui_calendar_get_date(GUI_CALENDAR(appGUI->cal->calendar), 
                           &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
-    jump_to_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 
     gui_calendar_set_frame_cursor_thickness (GUI_CALENDAR (appGUI->cal->calendar), config.frame_cursor_thickness);
 
@@ -1648,6 +1789,7 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
                           G_CALLBACK(aux_cal_expander_cb), appGUI);
         gtk_expander_set_expanded (GTK_EXPANDER(appGUI->cal->aux_cal_expander), config.auxilary_calendars_state);
     }
+
 }
 
 /*------------------------------------------------------------------------------*/
