@@ -24,6 +24,9 @@
 
 #include "gui.h"
 
+#include "time_utils.h"
+#include "date_utils.h"
+
 enum {
     PREVIOUS_DAY = 0,
     TODAY,
@@ -54,6 +57,9 @@ void        set_day_info                            (guint dday, guint dmonth, g
 void        calendar_refresh_marks                  (GUI *appGUI);
 void        update_aux_calendars                    (GUI *appGUI);
 
+void        calendar_store_note                     (GUI *appGUI);
+DATE *      get_selected_date                       (GUI *appGUI);
+
 void        calendar_btn_prev_day                   (GUI *appGUI);
 void        calendar_btn_next_day                   (GUI *appGUI);
 void        calendar_btn_prev_week                  (GUI *appGUI);
