@@ -38,13 +38,6 @@
 
 /*------------------------------------------------------------------------------*/
 
-void
-insert_date_cb (GtkWidget *widget, gpointer data) {
-
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 window_date_calculator_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 
@@ -248,6 +241,9 @@ gchar tmpbuf[BUFFER_SIZE];
     days = (gint)get_number_of_days_in_month (date_from.month, date_from.year);
     if (date_from.day > days) {
         date_from.day = days;
+        gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, COLOR_BG_FAIL, appGUI);
+    } else {
+        gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, NULL, appGUI);
     }
 
     date_to.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
@@ -265,63 +261,47 @@ gchar tmpbuf[BUFFER_SIZE];
     days = (gint)get_number_of_days_in_month (date_to.month, date_to.year);
     if (date_to.day > days) {
         date_to.day = days;
-    }
-
-    days = calculate_date_time_diff (date_from, time_from, date_to, time_to,
-                                     &date_diff, &time_diff);
-
-    if (days == -1) {
-        sprintf (tmpbuf, "<big>%s</big>", _("Start date is after the end date!"));
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1), tmpbuf);
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1_2), "<big> </big>");
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_2), "<small> </small>");
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_a), "<small>\n </small>");
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_3), "<small> \n \n \n </small>");
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_1), FALSE);
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_1_2), FALSE);
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_2), FALSE);
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_3), FALSE);
+        gui_change_bg_widget_state (appGUI->cal->spinbutton_end_day, COLOR_BG_FAIL, appGUI);
     } else {
-        sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
-            date_diff.year, ngettext ("year", "years", date_diff.year),
-            date_diff.month, ngettext ("month", "months", date_diff.month),
-            date_diff.day, ngettext ("day", "days", date_diff.day));
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1), tmpbuf);
-
-        sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
-            time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
-            time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
-            time_diff.second, ngettext ("second", "seconds", time_diff.second));
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1_2), tmpbuf);
-
-        sprintf (tmpbuf, "<small>\n<i>%s:</i></small>", _("Alternative time units"));
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_a), tmpbuf);
-
-        sprintf (tmpbuf, "<small>(%s: %d %s, %d %s, %d %s, %d %s)</small>",
-            _("or"),
-            days, ngettext ("day", "days", days),
-            time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
-            time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
-            time_diff.second, ngettext ("second", "seconds", time_diff.second));
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_2), tmpbuf);
-
-        seconds = (guint64)time_diff.second + (guint64)time_diff.minute * 60 +
-                  (guint64)time_diff.hour * 3600 + (guint64)days * 24 * 3600;
-        minutes = seconds / 60;
-        hours = minutes / 60;
-        weeks = (gint)(hours / (24 * 7));
-        sprintf (tmpbuf, "<small>%llu %s\n%llu %s (%s)\n%llu %s (%s)\n%d %s (%s)</small>",
-            seconds, ngettext ("second", "seconds", seconds),
-            minutes, ngettext ("minute", "minutes", minutes), _("rounded down"),
-            hours, ngettext ("hour", "hours", hours), _("rounded down"),
-            weeks, ngettext ("week", "weeks", weeks), _("rounded down"));
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_3), tmpbuf);
-
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_1), TRUE);
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_1_2), TRUE);
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_2), TRUE);
-        gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_3), TRUE);
+        gui_change_bg_widget_state (appGUI->cal->spinbutton_end_day, NULL, appGUI);
     }
+
+    days = calculate_date_time_diff (date_from, time_from, date_to, time_to, &date_diff, &time_diff);
+
+    if (days == -1)
+        days = calculate_date_time_diff (date_to, time_to, date_from, time_from, &date_diff, &time_diff);
+
+    sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
+        date_diff.year, ngettext ("year", "years", date_diff.year),
+        date_diff.month, ngettext ("month", "months", date_diff.month),
+        date_diff.day, ngettext ("day", "days", date_diff.day));
+    gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1), tmpbuf);
+
+    sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
+        time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
+        time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
+        time_diff.second, ngettext ("second", "seconds", time_diff.second));
+    gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1_2), tmpbuf);
+
+    sprintf (tmpbuf, "<small>(%s: %d %s, %d %s, %d %s, %d %s)</small>",
+        _("or"),
+        days, ngettext ("day", "days", days),
+        time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
+        time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
+        time_diff.second, ngettext ("second", "seconds", time_diff.second));
+    gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_2), tmpbuf);
+
+    seconds = (guint64)time_diff.second + (guint64)time_diff.minute * 60 +
+              (guint64)time_diff.hour * 3600 + (guint64)days * 24 * 3600;
+    minutes = seconds / 60;
+    hours = minutes / 60;
+    weeks = (gint)(hours / (24 * 7));
+    sprintf (tmpbuf, "<small>%llu %s\n%llu %s (%s)\n%llu %s (%s)\n%d %s (%s)</small>",
+        seconds, ngettext ("second", "seconds", seconds),
+        minutes, ngettext ("minute", "minutes", minutes), _("rounded down"),
+        hours, ngettext ("hour", "hours", hours), _("rounded down"),
+        weeks, ngettext ("week", "weeks", weeks), _("rounded down"));
+    gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_3), tmpbuf);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -367,6 +347,12 @@ gchar tmpbuf[BUFFER_SIZE];
     second2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton2_end_second));
 
+    if (day > (gint)get_number_of_days_in_month (month, year)) {
+        gui_change_bg_widget_state (appGUI->cal->spinbutton2_start_day, COLOR_BG_FAIL, appGUI);
+    } else {
+        gui_change_bg_widget_state (appGUI->cal->spinbutton2_start_day, NULL, appGUI);
+    }
+
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->radiobutton_add)) == TRUE) {
     /* add */
         year += year2;
@@ -393,7 +379,7 @@ gchar tmpbuf[BUFFER_SIZE];
         julian += day2 + week2 * 7;
 
     } else {
-    /* substract */
+    /* subtract */
         year = year - year2 - (month2 / 12);
         month -= month2 % 12;
 
@@ -453,6 +439,37 @@ gchar tmpbuf[BUFFER_SIZE];
         }
         gtk_label_set_markup (GTK_LABEL (appGUI->cal->label2_result), tmpbuf);
     }
+
+    appGUI->cal->julian_jumpto = julian;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+jumpto_and_window_close_cb (GtkButton *button, gpointer user_data) {
+
+GUI *appGUI = (GUI *)user_data;
+gint year, month, day;
+
+GDate *cdate;
+
+    cdate = g_date_new_julian (appGUI->cal->julian_jumpto);
+
+    if (cdate != NULL) {
+        if (g_date_valid (cdate)) {
+            day = g_date_get_day (cdate);
+            month = g_date_get_month (cdate) - 1;
+            year = g_date_get_year (cdate);
+        }
+        g_date_free (cdate);
+    }
+
+    if (is_valid_date2 (day, month, year) == TRUE) {
+        jump_to_date (day, month, year, appGUI);
+        update_aux_calendars (appGUI);
+    }
+
+    window_date_calculator_close_cb (GTK_WIDGET(button), NULL, user_data);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -497,12 +514,14 @@ GSList    *radiobutton_add_group = NULL;
 GtkWidget *radiobutton_sub;
 GtkWidget *close_button;
 GtkWidget *hbox11;
+GtkWidget *hbox12;
 GtkWidget *hbox13;
 GtkWidget *hbox_bst;
 GtkWidget *hbox_bet;
 GtkWidget *hbox_b2st;
 GtkWidget *hbox_b2sn;
 GtkWidget *vbox_result;
+GtkWidget *jumpto_button;
 char      tmpbuf[BUFFER_SIZE];
 
     appGUI->cal->window_date_calculator = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -690,7 +709,7 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, button_start_clear, _("Reset time"), NULL);
     g_signal_connect (button_start_clear, "clicked", G_CALLBACK (reset_current_time_start_cb), appGUI);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Start date and time"));
+    sprintf (tmpbuf, "<b>%s:</b>", _("First date and time"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -855,7 +874,7 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, button_end_clear, _("Reset time"), NULL);
     g_signal_connect (button_end_clear, "clicked", G_CALLBACK (reset_current_time_end_cb), appGUI);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("End date and time"));
+    sprintf (tmpbuf, "<b>%s:</b>", _("Second date and time"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -897,11 +916,11 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_box_pack_start (GTK_BOX (vbox_result), appGUI->cal->label_result_2, TRUE, TRUE, 0);
 
     sprintf (tmpbuf, "<small>\n<i>%s:</i></small>", _("Alternative time units"));
-    appGUI->cal->label_a = gtk_label_new (tmpbuf);
-    gtk_widget_show (appGUI->cal->label_a);
-    gtk_box_pack_start (GTK_BOX (vbox_result), appGUI->cal->label_a, FALSE, FALSE, 0);
-    gtk_label_set_use_markup (GTK_LABEL (appGUI->cal->label_a), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->label_a), 0, 0.5);
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (vbox_result), label, FALSE, FALSE, 0);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
     appGUI->cal->label_result_3 = gtk_label_new ("");
     gtk_widget_show (appGUI->cal->label_result_3);
@@ -1082,7 +1101,7 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, button2_start_clear, _("Reset time"), NULL);
     g_signal_connect (button2_start_clear, "clicked", G_CALLBACK (reset_current_time_start2_cb), appGUI);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Date and time to add or substract from"));
+    sprintf (tmpbuf, "<b>%s:</b>", _("Date and time to add or subtract from"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -1230,7 +1249,7 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cal->radiobutton_add),radiobutton_add_group);
     radiobutton_add_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cal->radiobutton_add));
 
-    radiobutton_sub = gtk_radio_button_new_with_mnemonic (NULL, _("substract"));
+    radiobutton_sub = gtk_radio_button_new_with_mnemonic (NULL, _("subtract"));
     gtk_widget_show (radiobutton_sub);
     gtk_box_pack_start (GTK_BOX (hbox10), radiobutton_sub, FALSE, FALSE, 0);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_sub), radiobutton_add_group);
@@ -1249,7 +1268,7 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, button2_end_clear, _("Reset fields"), NULL);
     g_signal_connect (button2_end_clear, "clicked", G_CALLBACK (reset_addsub_time_cb), appGUI);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Time to add or substract"));
+    sprintf (tmpbuf, "<b>%s:</b>", _("Time to add or subtract"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -1271,10 +1290,26 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_container_set_border_width (GTK_CONTAINER (alignment), 8);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
+    hbox12 = gtk_hbox_new (FALSE, 8);
+    gtk_widget_show (hbox12);
+    gtk_container_add (GTK_CONTAINER (alignment), hbox12);
+/*    gtk_box_pack_start (GTK_BOX (alignment), hbox12, TRUE, TRUE, 4);*/
+
     appGUI->cal->label2_result = gtk_label_new ("-");
     gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label2_result), 1);
     gtk_widget_show (appGUI->cal->label2_result);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->cal->label2_result);
+/*    gtk_container_add (GTK_CONTAINER (alignment), appGUI->cal->label2_result);*/
+/*    gtk_container_add (GTK_BOX (hbox12), appGUI->cal->label2_result);*/
+    gtk_box_pack_start (GTK_BOX (hbox12), appGUI->cal->label2_result, TRUE, TRUE, 4);
+
+    if (config.default_stock_icons) {
+        jumpto_button = gtk_button_new_from_stock (GTK_STOCK_JUMP_TO);
+    } else {
+        jumpto_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_JUMPTO);
+    }
+    gtk_widget_show (jumpto_button);
+    g_signal_connect(jumpto_button, "clicked", G_CALLBACK(jumpto_and_window_close_cb), appGUI);
+    gtk_box_pack_end (GTK_BOX (hbox12), jumpto_button, FALSE, TRUE, 4);
 
     sprintf (tmpbuf, "<b>%s:</b>", _("Result"));
     label = gtk_label_new (tmpbuf);
