@@ -33,12 +33,65 @@
 #include "options_prefs.h"
 #include "calendar.h"
 #include "calendar_notes.h"
+#include "calendar_ical.h"
 #include "calendar_fullyear.h"
+#include "calendar_widget.h"
 #include "time_utils.h"
 #include "date_utils.h"
 #include "stock_icons.h"
 
 
+/*------------------------------------------------------------------------*/
+
+void
+fullyear_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    gtk_window_get_size (GTK_WINDOW(appGUI->cal->fullyear_window),
+                        &config.fy_window_size_x, &config.fy_window_size_y);
+
+    gtk_widget_destroy (appGUI->cal->fullyear_window);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+button_fullyear_window_close_cb (GtkButton *button, gpointer user_data) {
+
+    fullyear_window_close_cb (GTK_WIDGET(button), NULL, user_data);
+
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+select_date_day_cb (GtkWidget *widget, gpointer data) {
+
+gint year, month, day;
+GDate *cdate;
+
+    MESSAGE *msg = (MESSAGE *)data;
+
+    cdate = g_date_new_julian ((guint32)msg->data);
+
+    if (cdate != NULL) {
+        if (g_date_valid (cdate)) {
+            day = g_date_get_day (cdate);
+            month = g_date_get_month (cdate) - 1;
+            year = g_date_get_year (cdate);
+        }
+        g_date_free (cdate);
+    }
+
+    if (is_valid_date2 (day, month, year) == TRUE) {
+        jump_to_date (day, month, year, msg->appGUI);
+        update_aux_calendars (msg->appGUI);
+    }
+
+    fullyear_window_close_cb (GTK_WIDGET(widget), NULL, msg->appGUI);
+}
+
 /*------------------------------------------------------------------------*/
 
 void
@@ -50,6 +103,8 @@ gint cd, cm, cy;
 gchar d;
 gchar tmpbuf[BUFFER_SIZE];
 
+static MESSAGE selected_date[MAX_MONTHS*(MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1))];
+
 gint days_in_month[] = {
     31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
 };
@@ -83,7 +138,11 @@ gint days_in_month[] = {
         for(j=0; j < (MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1)); j++) {
 
             idx = i*(MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1))+j;
-            gtk_label_set_text(GTK_LABEL(appGUI->cal->calendar_labels[idx]), "");
+
+            gtk_button_set_label (GTK_BUTTON(appGUI->cal->calendar_buttons[idx]), "");
+            gtk_widget_set_sensitive (appGUI->cal->calendar_buttons[idx], FALSE);
+            g_signal_handlers_disconnect_by_func (G_OBJECT (appGUI->cal->calendar_buttons[idx]), 
+                                                  G_CALLBACK (select_date_day_cb), &selected_date[idx]);
 
             d = calendar_table[idx];
 
@@ -101,17 +160,25 @@ gint days_in_month[] = {
                     }
                 } else {    /* select current day */
                     if(i%2) {
-                        sprintf (tmpbuf, "<span foreground='medium blue' weight='bold'>(%d)</span>", d);
+                        sprintf (tmpbuf, "<span foreground='medium blue' weight='bold'><u>%d</u></span>", d);
                     } else {
-                        sprintf (tmpbuf, "<span weight='bold'>(%d)</span>", d);
+                        sprintf (tmpbuf, "<span weight='bold'><u>%d</u></span>", d);
                     }
 
                     if(!((j+1)%7) || !((j+2)%7)) {
-                        sprintf (tmpbuf, "<span foreground='firebrick' weight='bold'>(%d)</span>", d);
+                        sprintf (tmpbuf, "<span foreground='firebrick' weight='bold'><u>%d</u></span>", d);
                     }
                 }
 
-                gtk_label_set_markup (GTK_LABEL (appGUI->cal->calendar_labels[idx]), tmpbuf);
+                if (strlen(tmpbuf)) {
+                    selected_date[idx].data = (gpointer) date_to_julian(d, i, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cal->fy_spinbutton)));
+                    selected_date[idx].appGUI = appGUI;
+                    g_signal_connect (G_OBJECT (appGUI->cal->calendar_buttons[idx]), "clicked",
+                                      G_CALLBACK (select_date_day_cb), &selected_date[idx]);
+                    gtk_label_set_markup(GTK_LABEL(GTK_BIN(appGUI->cal->calendar_buttons[idx])->child), tmpbuf);
+                    gtk_widget_set_sensitive (appGUI->cal->calendar_buttons[idx], TRUE);
+                }
+
             }
         }
     }
@@ -182,26 +249,18 @@ gint year;
 
 /*------------------------------------------------------------------------*/
 
-void
-fullyear_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    gtk_window_get_size (GTK_WINDOW(appGUI->cal->fullyear_window),
-                        &config.fy_window_size_x, &config.fy_window_size_y);
-
-    gtk_widget_destroy (appGUI->cal->fullyear_window);
-}
-
-/*------------------------------------------------------------------------------*/
+#ifdef HAVE_LIBICAL
 
 void
-button_fullyear_window_close_cb (GtkButton *button, gpointer user_data) {
+browse_ical_events_cb (GtkWidget *widget, gpointer data) {
 
-    fullyear_window_close_cb (GTK_WIDGET(button), NULL, user_data);
+    GUI *appGUI = (GUI *)data;
+    ical_events_browser (appGUI);
 
 }
 
+#endif  /* HAVE_LIBICAL */
+
 /*------------------------------------------------------------------------------*/
 
 gint 
@@ -221,6 +280,35 @@ fullyear_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+year_info_cb (GtkWidget *widget, gpointer data) {
+
+gint i, year, w_days;
+gchar tmpbuf[BUFFER_SIZE];
+
+    GUI *appGUI = (GUI *)data;
+
+    year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cal->fy_spinbutton));
+
+    w_days = 0;
+
+    for (i = 1; i <= 12; i++) {
+        w_days += get_weekend_days (i, year);
+    }
+
+    g_snprintf(tmpbuf, BUFFER_SIZE-1, "%s: %d\n%s: %s\n\n%s: %s\n\n%s: %d\n%s: %d\n%s: %d (%.1f%%)", 
+               _("Year"), year, _("Leap year"), is_leap_year(year) ? _("Yes"):_("No"),
+               _("Chinese year animal"), get_chinese_year_name (year),
+               _("Number of days"), get_days_per_year(year),
+               _("Number of weekends"), weeks_in_year (year),
+               _("Number of weekend days"), w_days, (double)w_days/get_days_per_year(year)*100.0);
+
+    gui_create_dialog(GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->cal->fullyear_window));
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 calendar_create_fullyear_window (GUI *appGUI) {
 
@@ -230,12 +318,16 @@ GtkWidget   *hbuttonbox;
 GtkWidget   *close_button;
 GtkWidget   *hbox1;
 GtkWidget   *prev_button;
+GtkWidget   *info_button;
 GtkObject   *fy_spinbutton_adj;
 GtkWidget   *next_button;
 GtkWidget   *fycal_scrolledwindow;
 GtkWidget   *fycal_viewport;
 GtkWidget   *vseparator;
 GtkWidget   *label;
+#ifdef HAVE_LIBICAL
+GtkWidget   *button;
+#endif  /* HAVE_LIBICAL */
 gchar       tmpbuf[BUFFER_SIZE], buffer[BUFFER_SIZE];
 gint        i, j, idx;
 GDate       *cdate = NULL;
@@ -243,7 +335,7 @@ GDate       *cdate = NULL;
     cdate = g_date_new();
     if (cdate != NULL) {
         g_date_set_day (cdate, get_current_day());
-        g_date_set_month (cdate, get_current_month());
+        g_date_set_month (cdate, get_current_month()+1);
         g_date_set_year (cdate, get_current_year());
     }
 
@@ -274,7 +366,7 @@ GDate       *cdate = NULL;
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_padding (GTK_MISC (label), 0, 4);
 
-    fy_spinbutton_adj = gtk_adjustment_new (2007, JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 10);
+    fy_spinbutton_adj = gtk_adjustment_new (get_current_year(), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 10);
     appGUI->cal->fy_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (fy_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->fy_spinbutton);
     g_signal_connect(appGUI->cal->fy_spinbutton, "value-changed", G_CALLBACK(change_year_spin_button_cb), appGUI);
@@ -283,6 +375,22 @@ GDate       *cdate = NULL;
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), TRUE);
     gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), GTK_UPDATE_IF_VALID);
 
+    if (config.default_stock_icons) {
+        info_button = gui_stock_button(GTK_STOCK_INFO, FALSE);
+    } else {
+        info_button = gui_stock_button(OSMO_STOCK_BUTTON_INFO, FALSE);
+    }
+    GTK_WIDGET_UNSET_FLAGS(info_button, GTK_CAN_FOCUS);
+    gtk_widget_show (info_button);
+    g_signal_connect(info_button, "clicked", G_CALLBACK(year_info_cb), appGUI);
+    gtk_tooltips_set_tip (appGUI->osmo_tooltips, info_button, _("Year info"), NULL);
+    gtk_button_set_relief (GTK_BUTTON (info_button), GTK_RELIEF_NONE); 
+    gtk_box_pack_start (GTK_BOX (hbox1), info_button, FALSE, FALSE, 2);
+
+    vseparator = gtk_vseparator_new ();
+    gtk_widget_show (vseparator);
+    gtk_box_pack_start (GTK_BOX (hbox1), vseparator, FALSE, FALSE, 8);
+
     if (config.default_stock_icons) {
         prev_button = gui_stock_button(GTK_STOCK_GO_BACK, FALSE);
     } else {
@@ -319,6 +427,18 @@ GDate       *cdate = NULL;
     gtk_button_set_relief (GTK_BUTTON (next_button), GTK_RELIEF_NONE); 
     gtk_box_pack_start (GTK_BOX (hbox1), next_button, FALSE, FALSE, 2);
 
+#ifdef HAVE_LIBICAL
+    
+    if (appGUI->calendar_only == FALSE) {
+        button = gtk_button_new_with_label (_("Browse iCal events"));
+        GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
+        gtk_widget_show (button);
+        gtk_box_pack_end (GTK_BOX (hbox1), button, FALSE, FALSE, 2);
+        g_signal_connect(button, "clicked", G_CALLBACK(browse_ical_events_cb), appGUI);
+    }
+
+#endif  /* HAVE_LIBICAL */
+
     fycal_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_show (fycal_scrolledwindow);
     gtk_box_pack_start (GTK_BOX (vbox1), fycal_scrolledwindow, TRUE, TRUE, 0);
@@ -478,9 +598,11 @@ GDate       *cdate = NULL;
 
             idx = i*(MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1))+j;
 
-                appGUI->cal->calendar_labels[idx] = gtk_label_new (NULL);
-                gtk_widget_show (appGUI->cal->calendar_labels[idx]);
-                gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table), appGUI->cal->calendar_labels[idx], j+2, j+3, i+2, i+3,
+                appGUI->cal->calendar_buttons[idx] = gtk_button_new ();
+                GTK_WIDGET_UNSET_FLAGS(appGUI->cal->calendar_buttons[idx], GTK_CAN_FOCUS);
+                gtk_button_set_relief (GTK_BUTTON(appGUI->cal->calendar_buttons[idx]), GTK_RELIEF_NONE);
+                gtk_widget_show (appGUI->cal->calendar_buttons[idx]);
+                gtk_table_attach (GTK_TABLE (appGUI->cal->fycal_table), appGUI->cal->calendar_buttons[idx], j+2, j+3, i+2, i+3,
                                  (GtkAttachOptions) (GTK_FILL),
                                  (GtkAttachOptions) (0), 0, 0);
         }
