@@ -240,23 +240,23 @@ gchar *color_str;
 
     appGUI->cal->notes_list = NULL;
 
-    if (g_file_test (prefs_get_config_filename(NOTES_FILENAME), G_FILE_TEST_IS_REGULAR) == FALSE) 
+    if (g_file_test (prefs_get_config_filename(CALENDAR_NOTES_FILENAME), G_FILE_TEST_IS_REGULAR) == FALSE) 
         return;
 
-    if((doc = xmlParseFile(prefs_get_config_filename(NOTES_FILENAME)))) {
+    if((doc = xmlParseFile(prefs_get_config_filename(CALENDAR_NOTES_FILENAME)))) {
 
         if(!(node = xmlDocGetRootElement(doc))) {
             return;
         }
 
-        if(!xmlStrcmp(node->name, (xmlChar *) NOTES_NAME)) {
+        if(!xmlStrcmp(node->name, (xmlChar *) CALENDAR_NOTES_NAME)) {
 
             /* read note */
             node = node->xmlChildrenNode;
 
             while (node != NULL) {
 
-                if(!xmlStrcmp(node->name, (xmlChar *) DAY_CATEGORIES_NAME)) {
+                if(!xmlStrcmp(node->name, (xmlChar *) CALENDAR_DAY_CATEGORIES_NAME)) {
 
                     category_node = node->xmlChildrenNode;
 
@@ -357,10 +357,10 @@ gchar temp[BUFFER_SIZE];
     doc = xmlNewDoc((const xmlChar *) "1.0");
     attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
 
-    main_node = xmlNewNode(NULL, (const xmlChar *) NOTES_NAME);
+    main_node = xmlNewNode(NULL, (const xmlChar *) CALENDAR_NOTES_NAME);
     xmlDocSetRootElement(doc, main_node);
 
-    node = xmlNewChild(main_node, NULL, (const xmlChar *) DAY_CATEGORIES_NAME, (xmlChar *) NULL);
+    node = xmlNewChild(main_node, NULL, (const xmlChar *) CALENDAR_DAY_CATEGORIES_NAME, (xmlChar *) NULL);
 
     i = 0;
 
@@ -387,7 +387,7 @@ gchar temp[BUFFER_SIZE];
         xmlNewChild(note_node, NULL, (const xmlChar *) "message", (xmlChar *) a->note);
     }
 
-    xmlSaveFormatFileEnc(prefs_get_config_filename(NOTES_FILENAME), doc, "utf-8", 1);
+    xmlSaveFormatFileEnc(prefs_get_config_filename(CALENDAR_NOTES_FILENAME), doc, "utf-8", 1);
     xmlFreeDoc(doc);
 }
 
