@@ -22,9 +22,9 @@
 #ifndef _CALENDAR_NOTES_H
 #define _CALENDAR_NOTES_H
 
-#define NOTES_NAME              "osmo_calendar_notes"
-#define DAY_CATEGORIES_NAME     "day_categories"
-#define NOTES_FILENAME          "calendar_notes.xml"
+#define CALENDAR_NOTES_NAME              "osmo_calendar_notes"
+#define CALENDAR_DAY_CATEGORIES_NAME     "day_categories"
+#define CALENDAR_NOTES_FILENAME          "calendar_notes.xml"
 
 struct note {
     guint day;
