@@ -181,7 +181,7 @@ guint32 date;
 
             for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
-                if (i != COLUMN_PHOTO) {
+                if (i != COLUMN_PHOTO && i != COLUMN_ID) {
                     if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
                         gtk_tree_model_get (model, iter, i, &date, -1);
                         if (date == 0) {
@@ -275,88 +275,91 @@ guint32 date;
 
         for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
-            if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
-                gtk_tree_model_get (model, &iter, i, &date, -1);
-                if (date == 0) {
-                    text = NULL;
-                } else {
-                    if (i == COLUMN_BIRTH_DAY_DATE) {
-                        text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+            if (i != COLUMN_ID) {
+
+                if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
+                    gtk_tree_model_get (model, &iter, i, &date, -1);
+                    if (date == 0) {
+                        text = NULL;
                     } else {
-                        text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                        if (i == COLUMN_BIRTH_DAY_DATE) {
+                            text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+                        } else {
+                            text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                        }
                     }
+                } else {
+                    gtk_tree_model_get (model, &iter, i, &text, -1);
                 }
-            } else {
-                gtk_tree_model_get (model, &iter, i, &text, -1);
-            }
 
-                if (i != COLUMN_PHOTO) {
+                    if (i != COLUMN_PHOTO && i != COLUMN_ID) {
 
-                    if (i == COLUMN_FIRST_NAME || i == COLUMN_SECOND_NAME || i == COLUMN_LAST_NAME) {
+                        if (i == COLUMN_FIRST_NAME || i == COLUMN_SECOND_NAME || i == COLUMN_LAST_NAME) {
 
-                        if (text != NULL) {
-                            gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1,
-                                                      "big", NULL);
-                            gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, " ", -1,
-                                                      "big", NULL);
-                        }
-
-                        if (i == COLUMN_LAST_NAME) {
-                            gtk_text_buffer_insert(text_buffer, &titer, "\n", -1);
-                        }
-
-                    } else if (text != NULL && i!= COLUMN_GROUP) {
-
-                        gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
-
-                        activate_home_phone = (i == COLUMN_HOME_PHONE_2 || i == COLUMN_HOME_PHONE_3 || i == COLUMN_HOME_PHONE_4) && strlen(text);
-                        activate_work_phone = (i == COLUMN_WORK_PHONE_2 || i == COLUMN_WORK_PHONE_3 || i == COLUMN_WORK_PHONE_4) && strlen(text);
-                        activate_cell_phone = (i == COLUMN_WORK_PHONE_2 || i == COLUMN_WORK_PHONE_3 || i == COLUMN_WORK_PHONE_4) && strlen(text);
-                        activate_email = (i == COLUMN_EMAIL_2 || i == COLUMN_EMAIL_3 || i == COLUMN_EMAIL_4) && strlen(text);
-                        activate_www = (i == COLUMN_WWW_2 || i == COLUMN_WWW_3 || i == COLUMN_WWW_4) && strlen(text);
-
-                        for(j=0;j<PATH_MAX;j++) space_line[j] = ' ';
-
-                        if ((i >= COLUMN_HOME_PHONE_1 && i <= COLUMN_HOME_PHONE_4)  ||
-                            (i >= COLUMN_WORK_PHONE_1 && i <= COLUMN_WORK_PHONE_4)  ||
-                            (i >= COLUMN_CELL_PHONE_1 && i <= COLUMN_CELL_PHONE_4)  ||
-                            (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) ||
-                            (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4)) {
-
-                            if ((activate_home_phone == FALSE && i == COLUMN_HOME_PHONE_1) ||
-                               (activate_work_phone == FALSE && i == COLUMN_WORK_PHONE_1)  ||
-                               (activate_cell_phone == FALSE && i == COLUMN_CELL_PHONE_1)  ||
-                               (activate_email == FALSE && i == COLUMN_EMAIL_1) ||
-                               (activate_www == FALSE && i == COLUMN_WWW_1)) {
-
-                                sprintf(tmpbuf, "%s: ", gettext(appGUI->cnt->contact_fields_tags_name[2*i]));
-                            } else {
-                                sprintf(tmpbuf, " ");
+                            if (text != NULL) {
+                                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1,
+                                                          "big", NULL);
+                                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, " ", -1,
+                                                          "big", NULL);
                             }
 
-                        } else {
-                            sprintf(tmpbuf, "%s: ", gettext(appGUI->cnt->contact_fields_tags_name[2*i]));
-                        }
+                            if (i == COLUMN_LAST_NAME) {
+                                gtk_text_buffer_insert(text_buffer, &titer, "\n", -1);
+                            }
 
-                        if (i != COLUMN_INFO) {
-                            space_line[appGUI->cnt->longest_tag_name - strlen(tmpbuf) + 2] = '\0';
-                            strcat(tmpbuf, space_line);
-                        }
-                        gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, tmpbuf, -1, "tag_name", NULL);
+                        } else if (text != NULL && i!= COLUMN_GROUP) {
 
-                        if (i == COLUMN_INFO) {
                             gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
-                        }
 
-                        if (i == COLUMN_BLOG || (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) || (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4)) { /* insert link */
-                            gui_url_insert_link(&appGUI->cnt->contacts_links_list, &appGUI->cnt->contacts_link_index, appGUI->cnt->contacts_desc_textview , &titer, config.contact_link_color, config.tags_font_size, text, FALSE, appGUI);
-                        } else {
-                             gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1, "normal", NULL);
+                            activate_home_phone = (i == COLUMN_HOME_PHONE_2 || i == COLUMN_HOME_PHONE_3 || i == COLUMN_HOME_PHONE_4) && strlen(text);
+                            activate_work_phone = (i == COLUMN_WORK_PHONE_2 || i == COLUMN_WORK_PHONE_3 || i == COLUMN_WORK_PHONE_4) && strlen(text);
+                            activate_cell_phone = (i == COLUMN_WORK_PHONE_2 || i == COLUMN_WORK_PHONE_3 || i == COLUMN_WORK_PHONE_4) && strlen(text);
+                            activate_email = (i == COLUMN_EMAIL_2 || i == COLUMN_EMAIL_3 || i == COLUMN_EMAIL_4) && strlen(text);
+                            activate_www = (i == COLUMN_WWW_2 || i == COLUMN_WWW_3 || i == COLUMN_WWW_4) && strlen(text);
+
+                            for(j=0;j<PATH_MAX;j++) space_line[j] = ' ';
+
+                            if ((i >= COLUMN_HOME_PHONE_1 && i <= COLUMN_HOME_PHONE_4)  ||
+                                (i >= COLUMN_WORK_PHONE_1 && i <= COLUMN_WORK_PHONE_4)  ||
+                                (i >= COLUMN_CELL_PHONE_1 && i <= COLUMN_CELL_PHONE_4)  ||
+                                (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) ||
+                                (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4)) {
+
+                                if ((activate_home_phone == FALSE && i == COLUMN_HOME_PHONE_1) ||
+                                   (activate_work_phone == FALSE && i == COLUMN_WORK_PHONE_1)  ||
+                                   (activate_cell_phone == FALSE && i == COLUMN_CELL_PHONE_1)  ||
+                                   (activate_email == FALSE && i == COLUMN_EMAIL_1) ||
+                                   (activate_www == FALSE && i == COLUMN_WWW_1)) {
+
+                                    sprintf(tmpbuf, "%s: ", gettext(appGUI->cnt->contact_fields_tags_name[2*i]));
+                                } else {
+                                    sprintf(tmpbuf, " ");
+                                }
+
+                            } else {
+                                sprintf(tmpbuf, "%s: ", gettext(appGUI->cnt->contact_fields_tags_name[2*i]));
+                            }
+
+                            if (i != COLUMN_INFO) {
+                                space_line[appGUI->cnt->longest_tag_name - strlen(tmpbuf) + 2] = '\0';
+                                strcat(tmpbuf, space_line);
+                            }
+                            gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, tmpbuf, -1, "tag_name", NULL);
+
+                            if (i == COLUMN_INFO) {
+                                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
+                            }
+
+                            if (i == COLUMN_BLOG || (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) || (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4)) { /* insert link */
+                                gui_url_insert_link(&appGUI->cnt->contacts_links_list, &appGUI->cnt->contacts_link_index, appGUI->cnt->contacts_desc_textview , &titer, config.contact_link_color, config.tags_font_size, text, FALSE, appGUI);
+                            } else {
+                                 gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1, "normal", NULL);
+                            }
                         }
                     }
-                }
 
-                g_free(text);
+                    g_free(text);
+            }
         }
 
         /* insert photo */
@@ -765,7 +768,7 @@ static gchar *contact_fields_tags_name[] = {
     N_("IM Gadu-Gadu"), "im_gg", N_("IM Yahoo"), "im_yahoo", N_("IM MSN"), "im_msn",
     N_("IM ICQ"), "im_icq", N_("IM AOL"), "im_aol",
     N_("IM Jabber"), "im_jabber", N_("IM Skype"), "im_skype", N_("IM Tlen"), "im_tlen",
-    N_("Blog"), "blog", N_("Photo"), "photo_path", N_("Additional info"), "additional_info"
+    N_("Blog"), "blog", N_("Photo"), "photo_path", N_("Additional info"), "additional_info", "ID", "id"
 };
 
 const gchar *ui_info =
@@ -795,22 +798,25 @@ guint n_entries = G_N_ELEMENTS (entries);
     appGUI->cnt->longest_tag_name = 0;
 
     for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
-        if (appGUI->cnt->longest_tag_name < strlen(gettext(contact_fields_tags_name[i*2]))) {
-            appGUI->cnt->longest_tag_name = strlen(gettext(contact_fields_tags_name[i*2]));
+        if (i != COLUMN_ID) {
+            if (appGUI->cnt->longest_tag_name < strlen(gettext(contact_fields_tags_name[i*2]))) {
+                appGUI->cnt->longest_tag_name = strlen(gettext(contact_fields_tags_name[i*2]));
+            }
         }
     }
 
-    label = gtk_label_new(NULL);
-    gtk_label_set_angle (GTK_LABEL(label), -90.0);
-    sprintf(tmpbuf, "<b>%s</b>", _("Contacts"));
-    gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
-
     vbox1 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox1);
     gtk_container_set_border_width (GTK_CONTAINER (vbox1), 8);
-    gtk_notebook_append_page(GTK_NOTEBOOK(appGUI->notebook), vbox1, label);
+    sprintf(tmpbuf, "<b>%s</b>", _("Contacts"));
+    gui_add_to_notebook (vbox1, tmpbuf, appGUI);
+
     appGUI->cnt->vbox = GTK_BOX(vbox1);
 
+    if (config.hide_contacts == TRUE) {
+        gtk_widget_hide(GTK_WIDGET(appGUI->cnt->vbox));
+    }
+
     /*-------------------------------------------------------------------------------------*/
 
     action_group = gtk_action_group_new ("_actions");
@@ -910,7 +916,7 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (top_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
     for(i=0; i< CONTACTS_NUM_COLUMNS; i++) {
-        if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
+        if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE || i == COLUMN_ID) {
             contact_columns_types[i] = G_TYPE_UINT;
         } else {
             contact_columns_types[i] = G_TYPE_STRING;
