@@ -232,12 +232,12 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
                         } else if (config.export_format == EXPORT_TO_CSV && header == TRUE && j == 0) {
 
                             for(i=n=0; i < CONTACTS_NUM_COLUMNS; i++) {
-                                if (i != COLUMN_PHOTO && config.export_fields[i] == '+') {
+                                if (i != COLUMN_PHOTO && i != COLUMN_ID && config.export_fields[i] == '+') {
                                     n++;
                                 }
                             }
                             for(i=m=0; i < CONTACTS_NUM_COLUMNS; i++) {
-                                if (i != COLUMN_PHOTO && config.export_fields[i] == '+') {
+                                if (i != COLUMN_PHOTO && i != COLUMN_ID && config.export_fields[i] == '+') {
                                     fprintf(filehandle, "%s", appGUI->cnt->contact_fields_tags_name[i*2]);
                                     if (m != n-1) {
                                         fprintf(filehandle, ",");
@@ -527,7 +527,7 @@ select_action_cb (GtkWidget *widget, gpointer user_data) {
 
     for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
-        if (i != COLUMN_PHOTO) {
+        if (i != COLUMN_PHOTO && i != COLUMN_ID) {
                 switch((gint) msg->data) {
 
                     case SELECT_ALL:
@@ -806,7 +806,7 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
 
     for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
-        if (i != COLUMN_PHOTO) {
+        if (i != COLUMN_PHOTO && i != COLUMN_ID) {
 
             appGUI->cnt->check_buttons[i] = gtk_check_button_new_with_mnemonic (appGUI->cnt->contact_fields_tags_name[i*2]);
 
