@@ -31,7 +31,8 @@
 #include "gui_utils.h"
 #include "contacts.h"
 #include "contacts_import.h"
-#include "calendar_utils.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "stock_icons.h"
 #include "options_prefs.h"
 
@@ -232,6 +233,11 @@ import_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data)
  
     GUI *appGUI = (GUI *)user_data;
 
+    gtk_window_get_size (GTK_WINDOW(appGUI->cnt->import_window),
+                        &config.contacts_import_win_w, &config.contacts_import_win_h);
+    gdk_window_get_root_origin (GDK_WINDOW(appGUI->cnt->import_window->window),
+                                &config.contacts_import_win_x, &config.contacts_import_win_y);
+
     gtk_widget_destroy(appGUI->cnt->import_window);
 
     if(appGUI->cnt->file_buffer != NULL) {
@@ -261,7 +267,7 @@ import_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     switch(event->keyval) {
         case GDK_Escape:
-            gtk_widget_destroy(appGUI->cnt->import_window);
+            import_window_close_cb (widget, NULL, appGUI);
             return TRUE;
     }
 
@@ -327,7 +333,7 @@ start_import_cb (GtkWidget *widget, gpointer data) {
 
 gint i, j, k, n, m, p;
 guint n_records;
-gchar *str, *field_str, *item;
+gchar *str, *field_str, *item, *text;
 GtkTreeIter iter, g_iter;
 gboolean g_flag;
 gchar tmpbuf[BUFFER_SIZE];
@@ -358,6 +364,13 @@ gchar tmpbuf[BUFFER_SIZE];
                 if (appGUI->cnt->field_type[i]) {
                     if ((field_str = csv_get_field(str, i+1)) != NULL) {
 
+                        if (g_utf8_validate(field_str, -1, NULL) == FALSE) {
+                            text = g_convert_with_fallback(field_str, -1, "utf-8", "iso-8859-1", 
+                                                           "?", NULL, NULL, NULL);
+                            g_free(field_str);
+                            field_str = text;
+                        }
+
                         p = strlen(field_str);
 
                         if (appGUI->cnt->field_type[i]-1 == COLUMN_FIRST_NAME){
@@ -518,9 +531,8 @@ GtkWidget *hbuttonbox;
 GtkWidget *cancel_button;
 GtkWidget *import_button;
 
-gchar *str, *field_str;
+gchar *str, *field_str, *text;
 guint record, fields, n_records, i, j;
-gint win_xpos, win_ypos;
 gchar tmpbuf[BUFFER_SIZE];
 static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
 
@@ -570,8 +582,11 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                 gtk_window_set_title (GTK_WINDOW (appGUI->cnt->import_window), _("Import contacts"));
                 gtk_container_set_border_width (GTK_CONTAINER (appGUI->cnt->import_window), 6);
 
-                gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->import_window), IMPORT_WINDOW_SIZE_X, IMPORT_WINDOW_SIZE_Y);
-                gtk_window_set_position(GTK_WINDOW(appGUI->cnt->import_window), GTK_WIN_POS_CENTER_ON_PARENT);
+                gtk_window_move (GTK_WINDOW (appGUI->cnt->import_window), 
+                                 config.contacts_import_win_x, config.contacts_import_win_y);
+                gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->import_window), 
+                                             config.contacts_import_win_w, config.contacts_import_win_h);
+
                 gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->import_window), GTK_WINDOW(appGUI->main_window));
                 gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->import_window), TRUE);
 
@@ -683,8 +698,6 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                 GTK_WIDGET_SET_FLAGS (import_button, GTK_CAN_DEFAULT);
                 g_signal_connect(import_button, "clicked", G_CALLBACK(start_import_cb), appGUI);
 
-                gtk_window_get_position (GTK_WINDOW(appGUI->cnt->import_window), &win_xpos, &win_ypos);
-                gtk_window_move (GTK_WINDOW (appGUI->cnt->import_window), win_xpos-IMPORT_WINDOW_SIZE_X/2, win_ypos-10);
                 gtk_widget_show(appGUI->cnt->import_window);
 
                 gtk_widget_set_sensitive (fields_table, FALSE);
@@ -753,6 +766,14 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
 
                     if (str != NULL) {
                         if ((field_str = csv_get_field(str, i+1)) != NULL) {
+
+                            if (g_utf8_validate(field_str, -1, NULL) == FALSE) {
+                                text = g_convert_with_fallback(field_str, -1, "utf-8", "iso-8859-1", 
+                                                               "?", NULL, NULL, NULL);
+                                g_free(field_str);
+                                field_str = text;
+                            }
+
                             gtk_label_set_text (GTK_LABEL(appGUI->cnt->value_labels[i]), field_str);
                             g_free(field_str);
                         }
