@@ -22,9 +22,6 @@
 #ifndef _CONTACTS_IMPORT_H
 #define _CONTACTS_IMPORT_H
 
-#define     IMPORT_WINDOW_SIZE_X    650
-#define     IMPORT_WINDOW_SIZE_Y    450
-
 #define     MAX_LINE_LENGTH         32768       /* number of chars per line */
 #define     MAX_FIELD_LENGTH        8192        /* number of chars per field */
 #define     FIELD_SEPARATOR         ','
