@@ -44,6 +44,21 @@
 
 /*------------------------------------------------------------------------------*/
 
+void
+contacts_fill_ids (GUI *appGUI) {
+
+GtkTreeIter iter;
+gint i;
+
+    i = 0;
+    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, NULL, i++)) {
+        gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_ID, i, -1);
+    }
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 contacts_item_entered_cb (GtkWidget *widget, gpointer data) {
 
@@ -90,37 +105,39 @@ const gchar *text;
 
     for(i=0; i<CONTACTS_NUM_COLUMNS; i++) {
 
-        text = NULL;
-        free_str = FALSE;
+        if (i != COLUMN_ID) {
+            text = NULL;
+            free_str = FALSE;
 
-        if (i == COLUMN_BIRTH_DAY_DATE) {
-            if (appGUI->cnt->birthday_date) {
-                gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, i, appGUI->cnt->birthday_date, -1);
-            }
-        } else  if (i == COLUMN_NAME_DAY_DATE) {
-            if (appGUI->cnt->nameday_date) {
-                gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, i, appGUI->cnt->nameday_date, -1);
-            }
-        } else {
-
-            if (i == COLUMN_GROUP) {
-                text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(appGUI->cnt->combobox_group));
-                free_str = TRUE;
-            } else if (i == COLUMN_INFO) {
-                text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview));
-                gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &iter_a, 0);
-                gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &iter_b, -1);
-                text = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_buffer), &iter_a, &iter_b, TRUE);
-                free_str = TRUE;
+            if (i == COLUMN_BIRTH_DAY_DATE) {
+                if (appGUI->cnt->birthday_date) {
+                    gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, i, appGUI->cnt->birthday_date, -1);
+                }
+            } else  if (i == COLUMN_NAME_DAY_DATE) {
+                if (appGUI->cnt->nameday_date) {
+                    gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, i, appGUI->cnt->nameday_date, -1);
+                }
             } else {
-                text = gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->contact_entries[i]));
-            }
 
-            if (text != NULL) {
-                if (strlen(text)) {
-                    gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, i, text, -1);
-                    if (free_str == TRUE) {
-                        g_free((gchar *)text);
+                if (i == COLUMN_GROUP) {
+                    text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(appGUI->cnt->combobox_group));
+                    free_str = TRUE;
+                } else if (i == COLUMN_INFO) {
+                    text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview));
+                    gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &iter_a, 0);
+                    gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &iter_b, -1);
+                    text = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_buffer), &iter_a, &iter_b, TRUE);
+                    free_str = TRUE;
+                } else {
+                    text = gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->contact_entries[i]));
+                }
+
+                if (text != NULL) {
+                    if (strlen(text)) {
+                        gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, i, text, -1);
+                        if (free_str == TRUE) {
+                            g_free((gchar *)text);
+                        }
                     }
                 }
             }
@@ -144,6 +161,7 @@ const gchar *text;
 
     set_export_active(appGUI);
     gui_systray_tooltip_update(appGUI);
+    contacts_fill_ids (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -188,6 +206,8 @@ gchar tmpbuf[BUFFER_SIZE];
 
         gtk_tree_path_free(sort_path);
     }
+
+    contacts_fill_ids (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -324,6 +344,16 @@ guint32 julian_day;
 
 /*------------------------------------------------------------------------------*/
 
+void
+select_date_ok_cb (GtkWidget *widget, gpointer data) {
+
+    MESSAGE *msg = (MESSAGE *)data;
+
+    select_date_selected_cb (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), msg);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 select_date_nodate_cb (GuiCalendar *s_calendar, gpointer user_data) {
 
@@ -352,6 +382,7 @@ GtkWidget *hbox1;
 GtkWidget *alignment;
 GtkWidget *nodate_button;
 GtkWidget *close_button;
+GtkWidget *ok_button;
 static MESSAGE msg_selected;
 
 
@@ -396,6 +427,18 @@ static MESSAGE msg_selected;
     g_signal_connect (G_OBJECT (nodate_button), "clicked",
                         G_CALLBACK (select_date_nodate_cb), &msg_selected);
 
+    if (config.default_stock_icons) {
+        ok_button = gui_stock_button(GTK_STOCK_OK, FALSE);
+    } else {
+        ok_button = gui_stock_button(OSMO_STOCK_BUTTON_OK, FALSE);
+    }
+    GTK_WIDGET_UNSET_FLAGS(ok_button, GTK_CAN_FOCUS);
+    gtk_button_set_relief (GTK_BUTTON(ok_button), GTK_RELIEF_NONE);
+    gtk_widget_show (ok_button);
+    gtk_box_pack_end (GTK_BOX (hbox1), ok_button, FALSE, FALSE, 0);
+    g_signal_connect (G_OBJECT (ok_button), "clicked",
+                        G_CALLBACK (select_date_ok_cb), &msg_selected);
+
     if (config.default_stock_icons) {
         close_button = gui_stock_button(GTK_STOCK_CLOSE, FALSE);
     } else {
@@ -411,7 +454,7 @@ static MESSAGE msg_selected;
     gtk_widget_show (msg->appGUI->cnt->select_date_window);
 
     gui_calendar_set_display_options (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
-                                      GUI_CALENDAR_SHOW_HEADING | GUI_CALENDAR_SHOW_DAY_NAMES | GUI_CALENDAR_WEEK_START_MONDAY);
+                                      (config.display_options & !GUI_CALENDAR_NO_MONTH_CHANGE) | GUI_CALENDAR_SHOW_HEADING | GUI_CALENDAR_SHOW_DAY_NAMES);
 
     if (msg->data == (gpointer)COLUMN_BIRTH_DAY_DATE) {
         if (g_date_valid_julian(msg->appGUI->cnt->birthday_date)) {
@@ -623,7 +666,7 @@ gchar *contact_replace_tags[] = {
     gtk_table_attach (GTK_TABLE (table), appGUI->cnt->combobox_group, 2, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
-    create_category_combobox (GTK_COMBO_BOX(appGUI->cnt->combobox_group), appGUI->opt->contacts_group_store, TRUE);
+    gui_create_category_combobox (GTK_COMBO_BOX(appGUI->cnt->combobox_group), appGUI->opt->contacts_group_store, TRUE);
 
     gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->combobox_group), 0);
 
@@ -1042,41 +1085,43 @@ gchar *contact_replace_tags[] = {
         if (gtk_tree_selection_get_selected (appGUI->cnt->contacts_list_selection, &model, &iter)) {
 
 
-            for(i=0; i<CONTACTS_NUM_COLUMNS; i++) {
+            for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
-                if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
-                    gtk_tree_model_get (model, &iter, i, &date, -1);
-                    if (date == 0) {
-                        text = NULL;
-                    } else {
-                        if (i == COLUMN_BIRTH_DAY_DATE) {
-                            appGUI->cnt->birthday_date = date;
-                            text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+                if (i != COLUMN_ID) {
+
+                    if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
+                        gtk_tree_model_get (model, &iter, i, &date, -1);
+                        if (date == 0) {
+                            text = NULL;
                         } else {
-                            appGUI->cnt->nameday_date = date;
-                            text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                            if (i == COLUMN_BIRTH_DAY_DATE) {
+                                appGUI->cnt->birthday_date = date;
+                                text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL));
+                            } else {
+                                appGUI->cnt->nameday_date = date;
+                                text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY));
+                            }
                         }
-                    }
-                } else {
-                    gtk_tree_model_get (model, &iter, i, &text, -1);
-                }
-
-                if (text != NULL) {
-                    if (i == COLUMN_GROUP) {
-                        gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->combobox_group),
-                                                 gui_list_store_get_text_index (appGUI->opt->contacts_group_store, text));
-                    } else if (i == COLUMN_INFO) {
-                        text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview));
-                        gui_clear_text_buffer (text_buffer, &titer);
-                        gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &titer, 0);
-                        gtk_text_buffer_insert(text_buffer, &titer, text, -1);
-                        gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview), text_buffer);
                     } else {
-                        gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->contact_entries[i]), text);
+                        gtk_tree_model_get (model, &iter, i, &text, -1);
                     }
-                    g_free(text);
-                }
 
+                    if (text != NULL) {
+                        if (i == COLUMN_GROUP) {
+                            gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->combobox_group),
+                                                     gui_list_store_get_text_index (appGUI->opt->contacts_group_store, text));
+                        } else if (i == COLUMN_INFO) {
+                            text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview));
+                            gui_clear_text_buffer (text_buffer, &titer);
+                            gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &titer, 0);
+                            gtk_text_buffer_insert(text_buffer, &titer, text, -1);
+                            gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview), text_buffer);
+                        } else {
+                            gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->contact_entries[i]), text);
+                        }
+                        g_free(text);
+                    }
+                }
             }
 
             show_hide_multiple_fields(appGUI);
@@ -1167,20 +1212,22 @@ gchar tmpbuf[BUFFER_SIZE];
 
                             for (j = COLUMN_GROUP; j < CONTACTS_NUM_COLUMNS; j++) {
 
-                                if ((!xmlStrcmp(cnode->name, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1]))) {
+                                if (j != COLUMN_ID) {
+                                    if ((!xmlStrcmp(cnode->name, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1]))) {
 
-                                    if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
-                                        key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                                        if (key != NULL) {
-                                            sscanf((gchar *) key, "%d", &date);
-                                            gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, date, -1);
-                                            xmlFree(key);
-                                        }
-                                    } else {
-                                        key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                                        if (key != NULL) {
-                                            gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, key, -1);
-                                            xmlFree(key);
+                                        if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
+                                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
+                                            if (key != NULL) {
+                                                sscanf((gchar *) key, "%d", &date);
+                                                gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, date, -1);
+                                                xmlFree(key);
+                                            }
+                                        } else {
+                                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
+                                            if (key != NULL) {
+                                                gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, key, -1);
+                                                xmlFree(key);
+                                            }
                                         }
                                     }
                                 }
@@ -1205,9 +1252,9 @@ gchar tmpbuf[BUFFER_SIZE];
         xmlFreeDoc(doc);
     }
 
+    contacts_fill_ids (appGUI);
 }
 
-
 /*------------------------------------------------------------------------------*/
 
 void
@@ -1248,21 +1295,26 @@ gchar temp[BUFFER_SIZE];
 
         for (j = COLUMN_GROUP; j < CONTACTS_NUM_COLUMNS; j++) {
 
-            if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
+            if (j != COLUMN_ID) {
 
-                gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &date, -1);
-                sprintf(temp, "%d", date);
-                xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1], (xmlChar *) temp);
+                if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
 
-            } else {
+                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &date, -1);
+                    sprintf(temp, "%d", date);
+                    xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1], (xmlChar *) temp);
 
-                gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &item, -1);
+                } else {
 
-                if (item != NULL) {
-                    if (strlen(item)) {
-                        xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1], 
-                                    (xmlChar *) item);
+                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &item, -1);
+
+                    if (item != NULL) {
+                        if (strlen(item)) {
+                            xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1], 
+                                        (xmlChar *) item);
+                        }
                     }
+
+                    g_free (item);
                 }
             }
         }
