@@ -32,6 +32,11 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 
+#include <config.h>
+
+#ifdef HAVE_LIBGRINGOTTS
+#include <libgringotts.h>
+#endif  /* HAVE_LIBGRINGOTTS */
 
 #define     MAX_MONTHS      12
 #define     MAX_WEEKS       6
@@ -42,21 +47,25 @@ enum notebook_page {
     PAGE_CALENDAR = 0,
     PAGE_TASKS,
     PAGE_CONTACTS,
+#ifdef HAVE_LIBGRINGOTTS
+    PAGE_NOTES,
+#endif  /* HAVE_LIBGRINGOTTS */
     PAGE_OPTIONS,
     PAGE_ABOUT,
     NUMBER_OF_TABS
 };
 
 enum {                  /* tasks columns */
-    COLUMN_DONE = 0,
-    COLUMN_DUE_DATE,
-    COLUMN_DUE_DATE_JULIAN,
-    COLUMN_START_DATE_JULIAN,
-    COLUMN_PRIORITY,
-    COLUMN_CATEGORY,
-    COLUMN_SUMMARY,
-    COLUMN_DESCRIPTION,
-    COLUMN_COLOR,
+    TA_COLUMN_DONE = 0,
+    TA_COLUMN_DUE_DATE,
+    TA_COLUMN_DUE_DATE_JULIAN,
+    TA_COLUMN_START_DATE_JULIAN,
+    TA_COLUMN_PRIORITY,
+    TA_COLUMN_CATEGORY,
+    TA_COLUMN_SUMMARY,
+    TA_COLUMN_DESCRIPTION,
+    TA_COLUMN_COLOR,
+    TA_COLUMN_BOLD,
     TASKS_NUM_COLUMNS
 };
 
@@ -82,6 +91,7 @@ enum {                  /* contacts columns */
 
     COLUMN_IM_GG, COLUMN_IM_YAHOO, COLUMN_IM_MSN, COLUMN_IM_ICQ, COLUMN_IM_AOL, 
     COLUMN_IM_JABBER, COLUMN_IM_SKYPE, COLUMN_IM_TLEN, COLUMN_BLOG, COLUMN_PHOTO, COLUMN_INFO,
+    COLUMN_ID,
     CONTACTS_NUM_COLUMNS
 };
 
@@ -107,6 +117,9 @@ typedef struct {
     guint prev_month;
     guint prev_year;
 
+    /* used for 'jump to' button in date calculator */
+    guint julian_jumpto;
+
     /* day notes */
     GSList *notes_list;
     GtkWidget *notes_button;
@@ -114,6 +127,7 @@ typedef struct {
     GtkWidget *note_label;
     GtkWidget *calendar_note_textview;
     GtkWidget *day_info_vbox;
+    GtkWidget *day_info_scrolledwindow;
     GtkWidget *time_label;
     GtkWidget *day_number_label;
     GtkWidget *day_number_year_label;
@@ -159,7 +173,7 @@ typedef struct {
     GtkWidget *fycal_table;
     GtkWidget *fy_spinbutton;
     GtkWidget *cyear_button;
-    GtkWidget *calendar_labels[MAX_MONTHS*(MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1))];
+    GtkWidget *calendar_buttons[MAX_MONTHS*(MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1))];
 
     /* jump to date */
     GtkWidget *jumpto_window;
@@ -198,7 +212,6 @@ typedef struct {
     GtkWidget *label_result_1_2;
     GtkWidget *label_result_2;
     GtkWidget *label_result_3;
-    GtkWidget *label_a;
     GtkWidget *spinbutton2_start_year;
     GtkWidget *spinbutton2_start_month;
     GtkWidget *spinbutton2_start_day;
@@ -215,6 +228,15 @@ typedef struct {
     GtkWidget *label2_result;
     GtkWidget *radiobutton_add;
     
+    /* iCalendar */
+    GtkWidget *events_window;
+    GtkWidget *ical_combobox;
+    GtkWidget *n_items_label;
+    GSList *ics_files_list;
+    GtkWidget *ical_events_list;
+    GtkTreeSelection *ical_events_list_selection;
+    GtkListStore *ical_events_list_store;
+
 } CALENDAR;
 
 
@@ -345,16 +367,73 @@ typedef struct {
 
 } CONTACTS;
 
+typedef struct {
+
+    /* notes toolbar */
+    GtkToolbar *notes_toolbar_selector;
+    GtkToolbar *notes_toolbar_editor;
+
+    GtkBox *vbox;
+    GtkWidget *vbox_selector;
+    GtkWidget *vbox_editor;
+
+    GtkUIManager *notes_uim_selector_widget;
+    GtkUIManager *notes_uim_editor_widget;
+
+    gboolean    editor_active;
+
+    /* selector */
+    GtkWidget *notes_list;
+    GtkListStore *notes_list_store;
+    GtkTreeSelection *notes_list_selection; 
+
+    GtkWidget *add_entry_window;
+    GtkWidget *edit_entry_window;
+    GtkWidget *enter_password_window;
+    GtkWidget *add_entry_ok_button;
+
+    GtkWidget *note_name_entry;
+    GtkWidget *password_entry;
+    GtkWidget *spassword_entry;
+    GtkWidget *category_combobox;
+
+#ifdef HAVE_LIBGRINGOTTS
+    gchar *filename;
+    GRG_CTX context;
+    GRG_KEY keyholder;
+#endif  /* HAVE_LIBGRINGOTTS */
+
+    /* category filter */
+    GtkTreeModel *notes_filter;
+    gint filter_index;
+    GtkWidget *cf_combobox;
+    GtkWidget *n_items_label;
+
+    /* editor */
+    GtkWidget *title_label;
+    GtkWidget *editor_textview;
+    gboolean changed;
+    gboolean find_next_flag;
+    gboolean buffer_check_modify_enable;
+    GtkWidget *find_hbox;
+    GtkWidget *find_entry;
+    GtkWidget *find_case_checkbutton;
+
+} NOTES;
 
 typedef struct {
 
     GtkWidget *calendar_options_radiobutton;
     GtkWidget *tasks_options_radiobutton;
     GtkWidget *contacts_options_radiobutton;
+#ifdef HAVE_LIBGRINGOTTS
+    GtkWidget *notes_options_radiobutton;
+#endif  /* HAVE_LIBGRINGOTTS */
     GtkWidget *general_options_radiobutton;
 
     gboolean callback_active;
     gint options_counter;
+    GtkBox *vbox;
 
     /* calendar */
     GtkWidget *calendar_vbox;
@@ -370,8 +449,8 @@ typedef struct {
     GtkWidget *show_week_numbers_checkbutton;
     GtkWidget *week_start_monday_checkbutton;
     GtkWidget *simple_view_in_fy_calendar_checkbutton;
-    GtkWidget *show_notes_in_info_panel_checkbutton;
     GtkWidget *enable_auxilary_calendars_checkbutton;
+    GtkWidget *strikethrough_past_notes_checkbutton;
     GtkWidget *enable_block_cursor_checkbutton;
     GtkWidget *day_name_font_entry;
     GtkWidget *calendar_font_entry;
@@ -388,6 +467,28 @@ typedef struct {
     GtkWidget *color_edit_picker;
     GtkWidget *color_edit_name_entry;
     GtkWidget *color_edit_ok_button;
+    GtkWidget *ical_edit_window;
+    GtkWidget *ical_edit_name_entry;
+    GtkWidget *ical_edit_filename_entry;
+    GtkWidget *ical_edit_filename_browse_button;
+    GtkWidget *ical_edit_ok_button;
+    GtkWidget *calendar_ical_files_add_button;
+    GtkWidget *calendar_ical_files_edit_button;
+    GtkWidget *calendar_ical_files_remove_button;
+    GtkWidget *calendar_ical_files_browse_button;
+    GtkWidget *calendar_ical_files_name_entry;
+    GtkWidget *calendar_ical_files_filename_entry;
+    GtkListStore *calendar_ical_files_store;
+    GtkWidget *calendar_ical_files_treeview;
+    GtkTreeSelection *calendar_ical_files_select;
+    GtkWidget *di_show_current_time_checkbutton;
+    GtkWidget *di_show_day_number_checkbutton;
+    GtkWidget *di_show_marked_days_checkbutton;
+    GtkWidget *di_show_week_number_checkbutton;
+    GtkWidget *di_show_weekend_days_checkbutton;
+    GtkWidget *di_show_moon_phase_checkbutton;
+    GtkWidget *di_show_notes_checkbutton;
+    GtkWidget *di_show_zodiac_sign_checkbutton;
 
     /* tasks */
     GtkWidget *tasks_vbox;
@@ -403,6 +504,7 @@ typedef struct {
     GtkWidget *tasks_category_remove_button;
     GtkWidget *tasks_sort_order_combobox;
     GtkWidget *tasks_sort_mode_combobox;
+    GtkWidget *ct_bold_items_checkbutton;
     GtkWidget *ct_delete_items_checkbutton;
     GtkWidget *ct_hide_items_checkbutton;
     GtkWidget *tasks_enable_rules_hint_checkbutton;
@@ -431,8 +533,24 @@ typedef struct {
     GtkWidget *contact_tag_color_picker;
     GtkWidget *contact_link_color_picker;
 
+    /* notes */
+    GtkWidget *notes_vbox;
+    GtkWidget *editor_font_entry;
+    GtkWidget *notes_enc_algorithm_combobox;
+    GtkWidget *notes_enc_hashing_combobox;
+    GtkWidget *notes_comp_algorithm_combobox;
+    GtkWidget *notes_comp_ratio_combobox;
+    GtkWidget *notes_enable_rules_hint_checkbutton;
+    GtkWidget *notes_category_entry;
+    GtkListStore *notes_category_store;
+    GtkWidget *notes_category_treeview;
+    GtkTreeSelection *notes_category_select;
+    GtkWidget *notes_category_add_button;
+    GtkWidget *notes_category_remove_button;
+
     /* general */
     GtkWidget *general_vbox;
+    GtkWidget *tabs_position_combobox;
     GtkWidget *date_format_combobox;
     GtkWidget *time_format_combobox;
     GtkWidget *entry_web_browser;
@@ -443,7 +561,10 @@ typedef struct {
     GtkWidget *remember_latest_tab_checkbutton;
     GtkWidget *enable_systray_checkbutton;
     GtkWidget *start_minimised_checkbutton;
-
+    GtkWidget *hide_calendar_checkbutton;
+    GtkWidget *hide_tasks_checkbutton;
+    GtkWidget *hide_contacts_checkbutton;
+    GtkWidget *hide_notes_checkbutton;
 
 } OPTIONS;
 
@@ -465,9 +586,11 @@ typedef struct {
     gint current_tab;
     gint number_of_tabs;
     
-    PangoFontDescription *fd_day_name;
-    PangoFontDescription *fd_calendar;
-    PangoFontDescription *fd_notes;
+    PangoFontDescription *fd_calendar_day_name;
+    PangoFontDescription *fd_calendar_cal;
+    PangoFontDescription *fd_calendar_notes;
+
+    PangoFontDescription *fd_notes_editor;
 
     gboolean hovering_over_link;
     GdkCursor *hand_cursor;
@@ -480,6 +603,7 @@ typedef struct {
     GtkWidget *help_radiobutton;
     GtkWidget *scrolled_window;
     GtkWidget *about_textview;
+    GtkBox *about_vbox;
     gint about_counter;
     gint about_link_index;
     GSList about_links_list;
@@ -491,6 +615,7 @@ typedef struct {
     CALENDAR *cal;
     TASKS *tsk;
     CONTACTS *cnt;
+    NOTES *nte;
 
     OPTIONS *opt;
 
@@ -502,6 +627,7 @@ typedef struct {
 } MESSAGE;
 
 void        gui_create_window               (GUI *appGUI);
+void        gui_add_to_notebook             (GtkWidget *widget, gchar *text, GUI *appGUI);
 void        gui_create_about                (GUI *appGUI);
 void        gui_quit_osmo                   (GUI *appGUI);
 void        gui_systray_initialize          (GUI *appGUI);
