@@ -29,6 +29,190 @@
 #include "gui_utils.h"
 #include "stock_icons.h"
 
+static gunichar TAG_CHAR = 0xe000;      /* Unicode chars in the Private Use Area. */
+
+/*------------------------------------------------------------------------------*/
+
+gint
+gui_get_combobox_items (GtkComboBox *combo_box) {
+    return gtk_tree_model_iter_n_children (gtk_combo_box_get_model (GTK_COMBO_BOX (combo_box)), NULL);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_create_category_combobox (GtkComboBox *combo_box, GtkListStore *store, gboolean none) {
+
+GtkTreeIter iter;
+gchar *category;
+gint i, n;
+
+    n = gui_get_combobox_items(combo_box);
+
+    gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), -1);
+
+    for (i = n-1; i >= 0; i--) {
+        gtk_combo_box_remove_text (GTK_COMBO_BOX (combo_box), i);
+    }
+
+    if (none == TRUE) {
+        gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("None"));
+    } else {
+        gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("All items"));
+    }
+
+    i = 0;
+
+    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(store), &iter, NULL, i++)) {
+
+        gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &category, -1);
+        gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), category);
+        g_free(category);
+    }
+
+}
+
+/*------------------------------------------------------------------------------*/
+
+gchar *
+gui_text_buffer_get_text_with_tags (GtkTextBuffer *buffer) {
+
+GtkTextIter start, prev;
+GSList *tags = NULL, *i;
+gchar tag_char_utf8[7] = {0};
+gchar *text = g_strdup (""), *oldtext = NULL, *tmp;
+gboolean done = FALSE;
+
+    gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &start);
+
+    g_unichar_to_utf8 (TAG_CHAR, tag_char_utf8);
+
+    prev = start;
+
+    while (!done)
+    {
+        tmp = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (buffer), &prev, &start, TRUE);
+        oldtext = text;
+        text = g_strconcat (text, tmp, NULL);
+        g_free (oldtext);
+        g_free (tmp);
+
+        tags = gtk_text_iter_get_toggled_tags (&start, TRUE);
+        for (i = tags; i; i = i->next)
+        {
+            gchar *name;
+            g_object_get (G_OBJECT (i->data), "name", &name, NULL);
+            oldtext = text;
+            text = g_strconcat (text, tag_char_utf8, name, tag_char_utf8, NULL);
+            g_free (oldtext);
+            g_free (name);
+        }
+        g_slist_free (tags);
+
+        tags = gtk_text_iter_get_toggled_tags (&start, FALSE);
+        for (i = tags; i; i = i->next)
+        {
+            gchar *name;
+            g_object_get (G_OBJECT (i->data), "name", &name, NULL);
+            oldtext = text;
+            text = g_strconcat (text, tag_char_utf8, "/", name, tag_char_utf8, NULL);
+            g_free (oldtext);
+            g_free (name);
+        }
+        g_slist_free (tags);
+
+        if (gtk_text_iter_is_end (&start))
+            done = TRUE;
+        prev = start;
+        gtk_text_iter_forward_to_tag_toggle (&start, NULL);
+    }
+
+    return text;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_text_buffer_set_text_with_tags (GtkTextBuffer *buffer, const gchar *text) {
+
+GtkTextIter start, end;
+GList *tags = NULL;
+gchar **tokens;
+gint count;
+gchar tag_char_utf8[7] = {0};
+
+    if (!text)
+        return;
+
+    gtk_text_buffer_begin_user_action (GTK_TEXT_BUFFER (buffer));
+
+    gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (buffer), &start, &end);
+    gtk_text_buffer_delete (GTK_TEXT_BUFFER (buffer), &start, &end);
+    gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (buffer), &start, &end);
+
+    g_unichar_to_utf8 (TAG_CHAR, tag_char_utf8);
+
+    tokens = g_strsplit (text, tag_char_utf8, 0);
+
+    for (count = 0; tokens[count]; count++)
+    {
+        if (count % 2 == 0)
+        {
+            gint offset;
+            GList *j;
+
+            offset = gtk_text_iter_get_offset (&end);
+            gtk_text_buffer_insert (GTK_TEXT_BUFFER (buffer), &end, tokens[count], -1);
+            gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &start, offset);
+
+            for (j = tags; j; j = j->next)
+            {
+                gtk_text_buffer_apply_tag_by_name (GTK_TEXT_BUFFER (buffer), j->data, &start, &end);
+            }
+        }
+        else
+        {
+            if (tokens[count][0] != '/')
+            {
+                tags = g_list_prepend (tags, tokens[count]);
+            }
+            else
+            {
+                GList *element = g_list_find_custom (tags, &(tokens[count][1]), (GCompareFunc) g_ascii_strcasecmp);
+
+                if (element)
+                {
+                    tags = g_list_delete_link (tags, element);
+                }
+            }
+        }
+    }
+
+    gtk_text_buffer_end_user_action (GTK_TEXT_BUFFER (buffer));
+
+    g_strfreev (tokens);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_change_bg_widget_state (GtkWidget *widget, gchar *color_str, GUI *appGUI) {
+
+GdkColor color;
+
+    if (color_str != NULL) {
+
+        gdk_color_parse (color_str, &color);
+        gtk_widget_modify_base (widget, GTK_STATE_NORMAL, &color);
+
+    } else {
+
+        gtk_widget_modify_base (widget, GTK_STATE_NORMAL, 
+                                &(appGUI->main_window)->style->base[GTK_WIDGET_STATE (appGUI->main_window)]);
+    }
+
+}
+
 /*------------------------------------------------------------------------------*/
 
 GdkPixbuf*
@@ -70,6 +254,8 @@ GtkWidget *label;
     gtk_box_pack_start (GTK_BOX (hbox1), label, TRUE, TRUE, 16);
 }
 
+/*------------------------------------------------------------------------------*/
+
 gint
 gui_create_dialog(gint dialog_type, gchar *message, GtkWindow *parent) {
 
