@@ -26,6 +26,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <config.h>
+#include <sys/stat.h>
 
 #include "gui.h"
 #include "calendar.h"
@@ -44,6 +45,7 @@ GUI *appGUI = NULL;
 CALENDAR *cal = NULL;
 TASKS *tsk = NULL;
 CONTACTS *cnt = NULL;
+NOTES *nte = NULL;
 OPTIONS *opt = NULL;
 GtkWidget *info_dialog;
 gchar tmpbuf[BUFFER_SIZE];
@@ -60,6 +62,8 @@ int fhandle;
     g_return_val_if_fail (tsk != NULL, -1);
     cnt = g_new0 (CONTACTS, 1);
     g_return_val_if_fail (cnt != NULL, -1);
+    nte = g_new0 (NOTES, 1);
+    g_return_val_if_fail (nte != NULL, -1);
 
     opt = g_new0 (OPTIONS, 1);
     g_return_val_if_fail (opt != NULL, -1);
@@ -68,6 +72,7 @@ int fhandle;
     appGUI->cal = cal;
     appGUI->tsk = tsk;
     appGUI->cnt = cnt;
+    appGUI->nte = nte;
     appGUI->opt = opt;
 
     /* default values */   
@@ -93,6 +98,10 @@ int fhandle;
 
     appGUI->opt->options_counter = 0;
 
+    gtk_set_locale();
+    bindtextdomain(PACKAGE, LOCALEDIR);
+    textdomain(PACKAGE);
+
     if (argc != 1) {
         if (argc == 2 && !strncmp(argv[1], "-cal", 4) && strlen(argv[1]) == 4) {
             appGUI->calendar_only = TRUE;
@@ -152,9 +161,7 @@ int fhandle;
 
     }
 
-    gtk_set_locale();
-    bindtextdomain(PACKAGE, LOCALEDIR);
-    textdomain(PACKAGE);
+    config.run_counter++;
 
     gui_create_window (appGUI);
 
@@ -172,6 +179,7 @@ int fhandle;
 
 finish:
     g_free(opt);
+    g_free(nte);
     g_free(cnt);
     g_free(tsk);
     g_free(cal);
