@@ -313,12 +313,31 @@ GtkTreeModel *model;
 
 /*------------------------------------------------------------------------------*/
 
-void
-gui_create_contacts_page (GtkWidget *vbox, GUI *appGUI) {
+void 
+contacts_group_cell_edited_cb (GtkCellRendererText *renderer, gchar *path, 
+                               gchar *new_text, gpointer user_data) {
 
-GtkWidget           *vbox8, *vbox9, *vbox10;
+GtkTreeIter iter;
+GtkTreeModel *model;
+  
+    GUI *appGUI = (GUI *)user_data;
+
+    if (g_ascii_strcasecmp (new_text, "") != 0) {
+        model = gtk_tree_view_get_model (GTK_TREE_VIEW(appGUI->opt->contacts_group_treeview));
+        if (gtk_tree_model_get_iter_from_string (model, &iter, path)) {
+            gtk_list_store_set(appGUI->opt->contacts_group_store, &iter, 0, new_text, -1);
+        }
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_create_contacts_options_page (GtkWidget *vbox, GUI *appGUI) {
+
+GtkWidget           *appearance_vbox, *sorting_vbox, *groups_vbox;
 GtkWidget           *label;
-GtkWidget           *hbox1;
+GtkWidget           *colors_hbox, *photo_hbox;
 GtkWidget           *frame;
 GtkWidget           *table;
 GtkWidget           *alignment;
@@ -326,9 +345,9 @@ GtkWidget           *scrolledwindow;
 GtkWidget           *contacts_group_table;
 GtkCellRenderer     *renderer;
 GtkTreeViewColumn   *column;
-gchar tmpbuf[BUFFER_SIZE];
 GdkColor            color;
 
+gchar tmpbuf[BUFFER_SIZE];
 
     appGUI->opt->contacts_vbox = gtk_vbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), appGUI->opt->contacts_vbox, FALSE, FALSE, 0);
@@ -349,13 +368,13 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox8 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox8);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox8);
+    appearance_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (appearance_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), appearance_vbox);
 
     table = gtk_table_new (4, 5, FALSE);
     gtk_widget_show (table);
-    gtk_box_pack_start (GTK_BOX (vbox8), table, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 4);
     gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
@@ -367,9 +386,9 @@ GdkColor            color;
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    hbox1 = gtk_hbox_new (FALSE, 8);
-    gtk_widget_show (hbox1);
-    gtk_table_attach (GTK_TABLE (table), hbox1, 1, 4, 0, 1,
+    colors_hbox = gtk_hbox_new (FALSE, 8);
+    gtk_widget_show (colors_hbox);
+    gtk_table_attach (GTK_TABLE (table), colors_hbox, 1, 4, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -380,7 +399,7 @@ GdkColor            color;
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->contact_tag_color_picker, _("Color of contact tags"), NULL);
     gdk_color_parse(config.contact_tag_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->contact_tag_color_picker), &color);
-    gtk_box_pack_start (GTK_BOX (hbox1), appGUI->opt->contact_tag_color_picker, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->contact_tag_color_picker, FALSE, FALSE, 0);
 
     appGUI->opt->contact_link_color_picker = gtk_color_button_new ();
     gtk_widget_show (appGUI->opt->contact_link_color_picker);
@@ -389,7 +408,7 @@ GdkColor            color;
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->contact_link_color_picker, _("Color of links"), NULL);
     gdk_color_parse(config.contact_link_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->contact_link_color_picker), &color);
-    gtk_box_pack_start (GTK_BOX (hbox1), appGUI->opt->contact_link_color_picker, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->contact_link_color_picker, FALSE, FALSE, 0);
 
     sprintf(tmpbuf, "%s:", _("Name font size"));
     label = gtk_label_new (tmpbuf);
@@ -415,7 +434,7 @@ GdkColor            color;
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 2, 3, 1, 2,
                     (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+                    (GtkAttachOptions) (GTK_FILL), 6, 0);
 
     appGUI->opt->tags_font_size_spinbutton_adj = gtk_adjustment_new (6, 6, 100, 1, 10, 10);
     appGUI->opt->tags_font_size_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (appGUI->opt->tags_font_size_spinbutton_adj), 1, 0);
@@ -436,9 +455,9 @@ GdkColor            color;
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    hbox1 = gtk_hbox_new (FALSE, 8);
-    gtk_widget_show (hbox1);
-    gtk_table_attach (GTK_TABLE (table), hbox1, 1, 4, 2, 3,
+    photo_hbox = gtk_hbox_new (FALSE, 8);
+    gtk_widget_show (photo_hbox);
+    gtk_table_attach (GTK_TABLE (table), photo_hbox, 1, 4, 2, 3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -446,7 +465,7 @@ GdkColor            color;
     gtk_widget_show (appGUI->opt->contacts_photo_size_combobox);
     g_signal_connect (G_OBJECT (appGUI->opt->contacts_photo_size_combobox), "changed",
                       G_CALLBACK(contacts_photo_size_changed_cb), appGUI);
-    gtk_box_pack_start (GTK_BOX (hbox1), appGUI->opt->contacts_photo_size_combobox, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (photo_hbox), appGUI->opt->contacts_photo_size_combobox, FALSE, FALSE, 0);
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->contacts_photo_size_combobox), _("Small"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->contacts_photo_size_combobox), _("Medium"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->contacts_photo_size_combobox), _("Large"));
@@ -464,7 +483,7 @@ GdkColor            color;
     gtk_widget_show (appGUI->opt->contacts_enable_rules_hint_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->contacts_enable_rules_hint_checkbutton), "toggled",
                       G_CALLBACK (contacts_enable_rules_hint_changed_cb), appGUI);
-    gtk_box_pack_start (GTK_BOX (vbox8), appGUI->opt->contacts_enable_rules_hint_checkbutton, TRUE, TRUE, 4);
+    gtk_box_pack_start (GTK_BOX (appearance_vbox), appGUI->opt->contacts_enable_rules_hint_checkbutton, TRUE, TRUE, 4);
 
 
     frame = gtk_frame_new (NULL);
@@ -483,9 +502,9 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox8 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox8);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox8);
+    appearance_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (appearance_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), appearance_vbox);
 
 
     appGUI->opt->contacts_select_first_entry_checkbutton = gtk_check_button_new_with_mnemonic (_("Select and show first item after search"));
@@ -493,14 +512,14 @@ GdkColor            color;
     gtk_widget_show (appGUI->opt->contacts_select_first_entry_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->contacts_select_first_entry_checkbutton), "toggled",
                       G_CALLBACK (contacts_select_first_entry_changed_cb), appGUI);
-    gtk_box_pack_start (GTK_BOX (vbox8), appGUI->opt->contacts_select_first_entry_checkbutton, TRUE, TRUE, 4);
+    gtk_box_pack_start (GTK_BOX (appearance_vbox), appGUI->opt->contacts_select_first_entry_checkbutton, TRUE, TRUE, 4);
 
     appGUI->opt->contacts_hide_group_column_checkbutton = gtk_check_button_new_with_mnemonic (_("Hide group column"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->contacts_hide_group_column_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->contacts_hide_group_column_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->contacts_hide_group_column_checkbutton), "toggled",
                       G_CALLBACK (contacts_hide_group_column_changed_cb), appGUI);
-    gtk_box_pack_start (GTK_BOX (vbox8), appGUI->opt->contacts_hide_group_column_checkbutton, TRUE, TRUE, 4);
+    gtk_box_pack_start (GTK_BOX (appearance_vbox), appGUI->opt->contacts_hide_group_column_checkbutton, TRUE, TRUE, 4);
 
 
     frame = gtk_frame_new (NULL);
@@ -519,13 +538,13 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox10 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox10);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox10);
+    groups_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (groups_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), groups_vbox);
 
     contacts_group_table = gtk_table_new (4, 3, FALSE);
     gtk_widget_show (contacts_group_table);
-    gtk_box_pack_start (GTK_BOX (vbox10), contacts_group_table, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (groups_vbox), contacts_group_table, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (contacts_group_table), 8);
     gtk_table_set_row_spacings (GTK_TABLE (contacts_group_table), 8);
     gtk_table_set_col_spacings (GTK_TABLE (contacts_group_table), 4);
@@ -561,6 +580,9 @@ GdkColor            color;
     gtk_widget_set_size_request (appGUI->opt->contacts_group_treeview, -1, 80);
 
     renderer = gtk_cell_renderer_text_new();
+    g_object_set (renderer, "editable", TRUE, "editable-set", TRUE, NULL);
+    g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (contacts_group_cell_edited_cb), appGUI);
+
     column = gtk_tree_view_column_new_with_attributes(NULL, renderer, "text", 0, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->opt->contacts_group_treeview), column);
 
@@ -608,13 +630,13 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox9 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox9);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox9);
+    sorting_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (sorting_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), sorting_vbox);
 
     table = gtk_table_new (1, 5, FALSE);
     gtk_widget_show (table);
-    gtk_box_pack_start (GTK_BOX (vbox9), table, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (sorting_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_row_spacings (GTK_TABLE (table), 4);
     gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 
