@@ -81,6 +81,17 @@ gint response;
 
 /*------------------------------------------------------------------------------*/
 
+void
+bold_items_cb (GtkToggleButton *togglebutton, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    config.tasks_high_in_bold = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->ct_bold_items_checkbutton));
+    apply_task_attributes (appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 hide_items_cb (GtkToggleButton *togglebutton, gpointer user_data) {
 
@@ -137,13 +148,13 @@ gchar *item;
         gtk_entry_set_text(GTK_ENTRY(appGUI->opt->tasks_category_entry), "");
         gtk_widget_set_sensitive(appGUI->opt->tasks_category_add_button, FALSE);
 
-        create_category_combobox (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), appGUI->opt->tasks_category_store, FALSE);
+        gui_create_category_combobox (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), appGUI->opt->tasks_category_store, FALSE);
         gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), 0);
 
-        apply_date_colors(appGUI);
+        apply_task_attributes (appGUI);
 
-        gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter));
-        update_n_items(appGUI);
+        gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter));
+        update_tasks_number (appGUI);
     }
 }
 
@@ -264,11 +275,11 @@ visible_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
     if (!appGUI->opt->callback_active) return;
 
     config.visible_due_date_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_due_date_checkbutton));
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_DUE_DATE], config.visible_due_date_column);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], config.visible_due_date_column);
     config.visible_category_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_category_checkbutton));
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_CATEGORY], config.visible_category_column);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], config.visible_category_column);
     config.visible_priority_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_priority_checkbutton));
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_PRIORITY], config.visible_priority_column);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], config.visible_priority_column);
 
 }
 
@@ -283,11 +294,11 @@ tasks_sort_order_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     config.tasks_sorting_order = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->tasks_sort_order_combobox));
     gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
-                                          COLUMN_DUE_DATE, config.tasks_sorting_order);
+                                          TA_COLUMN_DUE_DATE, config.tasks_sorting_order);
     gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
-                                          COLUMN_PRIORITY, config.tasks_sorting_order);
+                                          TA_COLUMN_PRIORITY, config.tasks_sorting_order);
     gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
-                                          COLUMN_DONE, config.tasks_sorting_order);
+                                          TA_COLUMN_DONE, config.tasks_sorting_order);
 
     gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter));
 }
@@ -303,11 +314,11 @@ tasks_sort_mode_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     config.tasks_sorting_mode = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->tasks_sort_mode_combobox));
     gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
-                                          COLUMN_DUE_DATE, config.tasks_sorting_order);
+                                          TA_COLUMN_DUE_DATE, config.tasks_sorting_order);
     gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
-                                          COLUMN_PRIORITY, config.tasks_sorting_order);
+                                          TA_COLUMN_PRIORITY, config.tasks_sorting_order);
     gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->tsk->tasks_sort, 
-                                          COLUMN_DONE, config.tasks_sorting_order);
+                                          TA_COLUMN_DONE, config.tasks_sorting_order);
 
     gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter));
 
@@ -347,13 +358,32 @@ GtkTreeModel *model;
 
 /*------------------------------------------------------------------------------*/
 
-void
-gui_create_tasks_page   (GtkWidget *vbox, GUI *appGUI) {
+void 
+tasks_category_cell_edited_cb (GtkCellRendererText *renderer, gchar *path, 
+                               gchar *new_text, gpointer user_data) {
 
-GtkWidget           *vbox5, *vbox6;
-GtkWidget           *vbox7, *vbox11, *vbox12;
+GtkTreeIter iter;
+GtkTreeModel *model;
+  
+    GUI *appGUI = (GUI *)user_data;
+
+    if (g_ascii_strcasecmp (new_text, "") != 0) {
+        model = gtk_tree_view_get_model (GTK_TREE_VIEW(appGUI->opt->tasks_category_treeview));
+        if (gtk_tree_model_get_iter_from_string (model, &iter, path)) {
+            gtk_list_store_set(appGUI->opt->tasks_category_store, &iter, 0, new_text, -1);
+        }
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_create_tasks_options_page   (GtkWidget *vbox, GUI *appGUI) {
+
+GtkWidget           *appearance_vbox, *categories_vbox;
+GtkWidget           *sorting_vbox, *tasks_opt_vbox, *visible_columns_vbox;
 GtkWidget           *label;
-GtkWidget           *hbox1;
+GtkWidget           *colors_hbox;
 GtkWidget           *frame;
 GtkWidget           *table;
 GtkWidget           *alignment;
@@ -362,9 +392,10 @@ GtkWidget           *scrolledwindow;
 GtkWidget           *tasks_category_table;
 GtkCellRenderer     *renderer;
 GtkTreeViewColumn   *column;
-gchar tmpbuf[BUFFER_SIZE];
 GdkColor            color;
 
+gchar tmpbuf[BUFFER_SIZE];
+
 
     appGUI->opt->tasks_vbox = gtk_vbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), appGUI->opt->tasks_vbox, FALSE, FALSE, 0);
@@ -385,19 +416,19 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox5 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox5);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox5);
+    appearance_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (appearance_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), appearance_vbox);
 
     table = gtk_table_new (3, 4, FALSE);
     gtk_widget_show (table);
-    gtk_box_pack_start (GTK_BOX (vbox5), table, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 4);
     gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
-    hbox1 = gtk_hbox_new (FALSE, 8);
-    gtk_widget_show (hbox1);
-    gtk_table_attach (GTK_TABLE (table), hbox1, 1, 2, 0, 1,
+    colors_hbox = gtk_hbox_new (FALSE, 8);
+    gtk_widget_show (colors_hbox);
+    gtk_table_attach (GTK_TABLE (table), colors_hbox, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -408,7 +439,7 @@ GdkColor            color;
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->due_today_color_picker, _("Color of items that are due today"), NULL);
     gdk_color_parse(config.due_today_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->due_today_color_picker), &color);
-    gtk_box_pack_start (GTK_BOX (hbox1), appGUI->opt->due_today_color_picker, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->due_today_color_picker, FALSE, FALSE, 0);
 
     appGUI->opt->due_7days_color_picker = gtk_color_button_new ();
     gtk_widget_show (appGUI->opt->due_7days_color_picker);
@@ -417,7 +448,7 @@ GdkColor            color;
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->due_7days_color_picker, _("Color of items that are due in the next 7 days"), NULL);
     gdk_color_parse(config.due_7days_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->due_7days_color_picker), &color);
-    gtk_box_pack_start (GTK_BOX (hbox1), appGUI->opt->due_7days_color_picker, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->due_7days_color_picker, FALSE, FALSE, 0);
 
     appGUI->opt->past_due_color_picker = gtk_color_button_new ();
     gtk_widget_show (appGUI->opt->past_due_color_picker);
@@ -426,7 +457,7 @@ GdkColor            color;
     gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->past_due_color_picker, _("Color of items that are past due"), NULL);
     gdk_color_parse(config.past_due_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->past_due_color_picker), &color);
-    gtk_box_pack_start (GTK_BOX (hbox1), appGUI->opt->past_due_color_picker, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->past_due_color_picker, FALSE, FALSE, 0);
 
     appGUI->opt->ti_font_entry = gtk_entry_new ();
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ti_font_entry, GTK_CAN_FOCUS);
@@ -489,13 +520,13 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox12 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox12);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox12);
+    visible_columns_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (visible_columns_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), visible_columns_vbox);
 
     table = gtk_table_new (1, 3, FALSE);
     gtk_widget_show (table);
-    gtk_box_pack_start (GTK_BOX (vbox12), table, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (visible_columns_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_row_spacings (GTK_TABLE (table), 4);
     gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 
@@ -543,13 +574,13 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox6 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox6);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox6);
+    categories_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (categories_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), categories_vbox);
 
     tasks_category_table = gtk_table_new (4, 3, FALSE);
     gtk_widget_show (tasks_category_table);
-    gtk_box_pack_start (GTK_BOX (vbox6), tasks_category_table, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (categories_vbox), tasks_category_table, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (tasks_category_table), 8);
     gtk_table_set_row_spacings (GTK_TABLE (tasks_category_table), 8);
     gtk_table_set_col_spacings (GTK_TABLE (tasks_category_table), 4);
@@ -585,6 +616,9 @@ GdkColor            color;
     gtk_widget_set_size_request (appGUI->opt->tasks_category_treeview, -1, 80);
 
     renderer = gtk_cell_renderer_text_new();
+    g_object_set (renderer, "editable", TRUE, "editable-set", TRUE, NULL);
+    g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (tasks_category_cell_edited_cb), appGUI);
+
     column = gtk_tree_view_column_new_with_attributes(NULL, renderer, "text", 0, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->opt->tasks_category_treeview), column);
 
@@ -632,13 +666,13 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox7 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox7);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox7);
+    sorting_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (sorting_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), sorting_vbox);
 
     table = gtk_table_new (1, 5, FALSE);
     gtk_widget_show (table);
-    gtk_box_pack_start (GTK_BOX (vbox7), table, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (sorting_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_row_spacings (GTK_TABLE (table), 4);
     gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 
@@ -706,16 +740,23 @@ GdkColor            color;
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
 
-    vbox11 = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (vbox11);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox11);
+    tasks_opt_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (tasks_opt_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), tasks_opt_vbox);
+
+    appGUI->opt->ct_bold_items_checkbutton = gtk_check_button_new_with_mnemonic (_("Show in bold tasks with high priority"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_bold_items_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->ct_bold_items_checkbutton);
+    gtk_box_pack_start (GTK_BOX (tasks_opt_vbox), appGUI->opt->ct_bold_items_checkbutton, FALSE, FALSE, 4);
+    g_signal_connect (G_OBJECT (appGUI->opt->ct_bold_items_checkbutton), "toggled",
+                      G_CALLBACK (bold_items_cb), appGUI);
 
     appGUI->opt->ct_hide_items_checkbutton = gtk_check_button_new_with_mnemonic (_("Hide completed tasks"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_hide_items_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->ct_hide_items_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->ct_hide_items_checkbutton), "toggled",
                       G_CALLBACK (hide_delete_changed_cb), appGUI);
-    gtk_box_pack_start (GTK_BOX (vbox11), appGUI->opt->ct_hide_items_checkbutton, FALSE, FALSE, 4);
+    gtk_box_pack_start (GTK_BOX (tasks_opt_vbox), appGUI->opt->ct_hide_items_checkbutton, FALSE, FALSE, 4);
     g_signal_connect (G_OBJECT (appGUI->opt->ct_hide_items_checkbutton), "toggled",
                       G_CALLBACK (hide_items_cb), appGUI);
 
@@ -724,7 +765,7 @@ GdkColor            color;
     gtk_widget_show (appGUI->opt->ct_delete_items_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->ct_delete_items_checkbutton), "toggled",
                       G_CALLBACK (hide_delete_changed_cb), appGUI);
-    gtk_box_pack_start (GTK_BOX (vbox11), appGUI->opt->ct_delete_items_checkbutton, FALSE, FALSE, 4);
+    gtk_box_pack_start (GTK_BOX (tasks_opt_vbox), appGUI->opt->ct_delete_items_checkbutton, FALSE, FALSE, 4);
     g_signal_connect (G_OBJECT (appGUI->opt->ct_delete_items_checkbutton), "toggled",
                       G_CALLBACK (delete_items_cb), appGUI);
 
