@@ -24,7 +24,7 @@
 
 #include "gui.h"
 
-void    gui_create_tasks_page   (GtkWidget *vbox, GUI *appGUI);
+void    gui_create_tasks_options_page   (GtkWidget *vbox, GUI *appGUI);
 
 #endif /* _OPTIONS_GUI_TASKS_H */
 
