@@ -79,6 +79,7 @@ gint i;
     config.window_size_y = 690;
     config.enable_tooltips = TRUE;
     config.latest_tab = 0;      /* calendar */
+    config.tabs_position = GTK_POS_TOP;
     config.remember_latest_tab = TRUE;
     config.default_stock_icons = FALSE;
     config.disable_underline_links = FALSE;
@@ -86,8 +87,13 @@ gint i;
     config.time_format = TIME_24;
     config.enable_systray = TRUE;
     config.start_minimised_in_systray = FALSE;
+    config.run_counter = 0;
     config.lastrun_date = get_julian_for_today();
     config.lastrun_time = get_seconds_for_today();
+    config.hide_calendar = FALSE;
+    config.hide_tasks = FALSE;
+    config.hide_contacts = FALSE;
+    config.hide_notes = FALSE;
     strncpy(config.web_browser, "firefox %s", MAXHELPERCMD-1);
     strncpy(config.email_client, "claws-mail --compose %s", MAXHELPERCMD-1);
 
@@ -101,21 +107,31 @@ gint i;
     config.timeline_end = 15*60;
     config.timeline_step = 60;
     config.mark_symbol = 1;
-    config.notes_in_info_panel = FALSE;
+    config.di_show_current_time = TRUE;
+    config.di_show_day_number = TRUE;
+    config.di_show_marked_days = TRUE;
+    config.di_show_week_number = TRUE;
+    config.di_show_weekend_days = TRUE;
+    config.di_show_moon_phase = TRUE;
+    config.di_show_notes = TRUE;
+    config.di_show_zodiac_sign = FALSE;
     config.cursor_type = CURSOR_FRAME;
     config.frame_cursor_thickness = 2;
-    config.enable_auxilary_calendars = FALSE;
-    config.auxilary_calendars_state = TRUE;
+    config.enable_auxilary_calendars = TRUE;
+    config.strikethrough_past_notes = FALSE;
+    config.auxilary_calendars_state = FALSE;
+    config.marker_type = 0;     /* circle */
     strncpy(config.header_color, "#004048", MAXCOLORNAME-1);
     strncpy(config.weekend_color, "#880000", MAXCOLORNAME-1);
     strncpy(config.selection_color, "#526565", MAXCOLORNAME-1);
     strncpy(config.mark_color, "#dddddd", MAXCOLORNAME-1);
-    strncpy(config.day_name_font, "Sans Bold 26", MAXFONTNAME-1);
-    strncpy(config.calendar_font, "Sans 20", MAXFONTNAME-1);
+    strncpy(config.day_name_font, "Sans Bold 20", MAXFONTNAME-1);
+    strncpy(config.calendar_font, "Sans 18", MAXFONTNAME-1);
     strncpy(config.notes_font, "Sans 11", MAXFONTNAME-1);
 
     /* tasks */
     config.tasks_rules_hint = TRUE;
+    config.tasks_high_in_bold = TRUE;
     config.hide_completed = FALSE;
     config.delete_completed = FALSE;
     config.tasks_pane_pos = 275;
@@ -170,6 +186,13 @@ gint i;
     config.export_fields[COLUMN_LAST_NAME] = '+';
     config.export_fields[COLUMN_NICK_NAME] = '+';
 
+    /* notes */
+    config.notes_rules_hint = TRUE;
+    config.notes_enc_algorithm = 1;     /* Serpent */
+    config.notes_enc_hashing = 1;       /* RIPEMD-160 */
+    config.notes_comp_algorithm = 0;    /* ZLib */
+    config.notes_comp_ratio = 3;        /* BEST */
+    strncpy(config.notes_editor_font, "Sans 11", MAXFONTNAME-1);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -179,7 +202,7 @@ prefs_read_config (void) {
 
 gboolean cfg_file;
 xmlDocPtr doc;
-xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node;
+xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_node;
 xmlChar *key;
 
     cfg_file = g_file_test(prefs_get_config_filename(CONFIG_FILENAME), G_FILE_TEST_IS_REGULAR);
@@ -258,6 +281,13 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "tabs_position"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.tabs_position);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(general_node->name, (const xmlChar *) "remember_latest_tab"))) {
                             key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -307,6 +337,13 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "run_counter"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.run_counter);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(general_node->name, (const xmlChar *) "lastrun_date"))) {
                             key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -321,6 +358,34 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "hide_calendar"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.hide_calendar);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "hide_tasks"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.hide_tasks);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "hide_contacts"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.hide_contacts);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "hide_notes"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.hide_notes);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(general_node->name, (const xmlChar *)"web_browser"))) {
                             key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -412,10 +477,59 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
-                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "notes_in_info_panel"))) {
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_current_time"))) {
                             key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
                             if (key != NULL)
-                                    sscanf((gchar *) key, "%d", &config.notes_in_info_panel);
+                                    sscanf((gchar *) key, "%d", &config.di_show_current_time);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_day_number"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.di_show_day_number);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_marked_days"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.di_show_marked_days);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_week_number"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.di_show_week_number);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_weekend_days"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.di_show_weekend_days);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_moon_phase"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.di_show_moon_phase);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_notes"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.di_show_notes);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "di_show_zodiac_sign"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.di_show_zodiac_sign);
                             xmlFree(key);
                         }
 
@@ -440,6 +554,13 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "strikethrough_past_notes"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.strikethrough_past_notes);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "auxilary_calendars_state"))) {
                             key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -447,6 +568,13 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "marker_type"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.marker_type);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(calendar_node->name, (const xmlChar *)"header_color"))) {
                             key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -516,6 +644,13 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(tasks_node->name, (const xmlChar *) "high_priority_in_bold"))) {
+                            key = xmlNodeListGetString(doc, tasks_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.tasks_high_in_bold);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(tasks_node->name, (const xmlChar *) "hide_completed"))) {
                             key = xmlNodeListGetString(doc, tasks_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -827,6 +962,61 @@ xmlChar *key;
                     }
                 }
 
+            /*---------------------------------------------------------------------------------------*/
+            /* notes */
+
+                if ((!xmlStrcmp(node->name, (const xmlChar *) "notes"))) {
+
+                    notes_node = node->xmlChildrenNode;
+
+                    while (notes_node != NULL) {
+
+                        if ((!xmlStrcmp(notes_node->name, (const xmlChar *) "rules_hint"))) {
+                            key = xmlNodeListGetString(doc, notes_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.notes_rules_hint);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(notes_node->name, (const xmlChar *) "enc_algorithm"))) {
+                            key = xmlNodeListGetString(doc, notes_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.notes_enc_algorithm);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(notes_node->name, (const xmlChar *) "enc_hashing"))) {
+                            key = xmlNodeListGetString(doc, notes_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.notes_enc_hashing);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(notes_node->name, (const xmlChar *) "comp_algorithm"))) {
+                            key = xmlNodeListGetString(doc, notes_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.notes_comp_algorithm);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(notes_node->name, (const xmlChar *) "comp_ratio"))) {
+                            key = xmlNodeListGetString(doc, notes_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.notes_comp_ratio);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(notes_node->name, (const xmlChar *)"editor_font"))) {
+                            key = xmlNodeListGetString(doc, notes_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    strncpy(config.notes_editor_font, (gchar *) key, MAXFONTNAME-1);
+                            xmlFree(key);
+                        }
+
+                        notes_node = notes_node->next;
+                    }
+                }
+
             /*---------------------------------------------------------------------------------------*/
 
             node = node->next;
@@ -847,7 +1037,7 @@ xmlChar *key;
 void prefs_write_config(void) {
 
 xmlDocPtr doc;
-xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node;
+xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_node;
 gchar tmpbuf[BUFFER_SIZE];
 
     doc = xmlNewDoc((const xmlChar *) "1.0");
@@ -872,6 +1062,8 @@ gchar tmpbuf[BUFFER_SIZE];
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "enable_tooltips", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.latest_tab);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "latest_tab", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.tabs_position);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "tabs_position", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.remember_latest_tab);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "remember_latest_tab", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.default_stock_icons);
@@ -886,10 +1078,20 @@ gchar tmpbuf[BUFFER_SIZE];
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "enable_systray", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.start_minimised_in_systray);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "start_minimised_in_systray", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.run_counter);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "run_counter", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.lastrun_date);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "lastrun_date", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.lastrun_time);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "lastrun_time", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.hide_calendar);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "hide_calendar", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.hide_tasks);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "hide_tasks", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.hide_contacts);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "hide_contacts", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.hide_notes);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "hide_notes", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXHELPERCMD, "%s", config.web_browser);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "web_browser", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXHELPERCMD, "%s", config.email_client);
@@ -919,16 +1121,34 @@ gchar tmpbuf[BUFFER_SIZE];
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "timeline_step", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.mark_symbol);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "mark_symbol", (xmlChar *) tmpbuf);
-    snprintf(tmpbuf, 32, "%d", config.notes_in_info_panel);
-    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "notes_in_info_panel", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_current_time);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_current_time", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_day_number);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_day_number", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_marked_days);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_marked_days", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_week_number);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_week_number", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_weekend_days);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_weekend_days", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_moon_phase);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_moon_phase", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_notes);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_notes", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.di_show_zodiac_sign);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "di_show_zodiac_sign", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.cursor_type);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "cursor_type", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.frame_cursor_thickness);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "frame_cursor_thickness", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.enable_auxilary_calendars);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "enable_auxilary_calendars", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.strikethrough_past_notes);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "strikethrough_past_notes", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.auxilary_calendars_state);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "auxilary_calendars_state", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.marker_type);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "marker_type", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXCOLORNAME, "%s", config.header_color);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "header_color", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXCOLORNAME, "%s", config.weekend_color);
@@ -952,6 +1172,8 @@ gchar tmpbuf[BUFFER_SIZE];
 
     snprintf(tmpbuf, 32, "%d", config.tasks_rules_hint);
     xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "rules_hint", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.tasks_high_in_bold);
+    xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "high_priority_in_bold", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.hide_completed);
     xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "hide_completed", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.delete_completed);
@@ -1044,6 +1266,25 @@ gchar tmpbuf[BUFFER_SIZE];
     snprintf(tmpbuf, 32, "%d", config.contacts_import_win_h);
     xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_import_win_h", (xmlChar *) tmpbuf);
 
+    /*---------------------------------------------------------------------------------------*/
+    /* notes */
+
+    notes_node = xmlNewNode(NULL, (const xmlChar *) "notes");
+    xmlAddChild(node, notes_node);
+
+    snprintf(tmpbuf, 32, "%d", config.notes_rules_hint);
+    xmlNewTextChild(notes_node, NULL, (const xmlChar *) "rules_hint", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.notes_enc_algorithm);
+    xmlNewTextChild(notes_node, NULL, (const xmlChar *) "enc_algorithm", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.notes_enc_hashing);
+    xmlNewTextChild(notes_node, NULL, (const xmlChar *) "enc_hashing", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.notes_comp_algorithm);
+    xmlNewTextChild(notes_node, NULL, (const xmlChar *) "comp_algorithm", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.notes_comp_ratio);
+    xmlNewTextChild(notes_node, NULL, (const xmlChar *) "comp_ratio", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, MAXFONTNAME, "%s", config.notes_editor_font);
+    xmlNewTextChild(notes_node, NULL, (const xmlChar *) "editor_font", (xmlChar *) tmpbuf);
+
     /*---------------------------------------------------------------------------------------*/
 
     xmlSaveFormatFile(prefs_get_config_filename(CONFIG_FILENAME), doc, 1);
