@@ -40,6 +40,7 @@ struct osmo_prefs
     gint        window_size_y;
     gint        enable_tooltips;
     gint        latest_tab;
+    gint        tabs_position;
     gint        remember_latest_tab;
     gint        default_stock_icons;
     gint        disable_underline_links;
@@ -47,8 +48,13 @@ struct osmo_prefs
     gint        time_format;
     gint        enable_systray;
     gint        start_minimised_in_systray;
+    gint        run_counter;
     gint        lastrun_date;
     gint        lastrun_time;
+    gint        hide_calendar;
+    gint        hide_tasks;
+    gint        hide_contacts;
+    gint        hide_notes;
     gchar       web_browser[MAXHELPERCMD];
     gchar       email_client[MAXHELPERCMD];
 
@@ -62,11 +68,20 @@ struct osmo_prefs
     gint        timeline_end;
     gint        timeline_step;
     gint        mark_symbol;
-    gint        notes_in_info_panel;
+    gint        di_show_current_time;
+    gint        di_show_day_number;
+    gint        di_show_marked_days;
+    gint        di_show_week_number;
+    gint        di_show_weekend_days;
+    gint        di_show_moon_phase;
+    gint        di_show_notes;
+    gint        di_show_zodiac_sign;
     gint        cursor_type;
     gint        frame_cursor_thickness;
     gint        enable_auxilary_calendars;
+    gint        strikethrough_past_notes;
     gint        auxilary_calendars_state;
+    gint        marker_type;
     gchar       header_color[MAXCOLORNAME];
     gchar       weekend_color[MAXCOLORNAME];
     gchar       selection_color[MAXCOLORNAME];
@@ -77,6 +92,7 @@ struct osmo_prefs
 
     /* TASKS */
     gint        tasks_rules_hint;
+    gint        tasks_high_in_bold;
     gint        hide_completed;
     gint        delete_completed;
     gint        tasks_pane_pos;
@@ -122,13 +138,20 @@ struct osmo_prefs
     gint        export_format;
     gchar       export_fields[MAXCONTACTFIELDS];
 
+    /* NOTES */
+    gint        notes_rules_hint;
+    gint        notes_enc_algorithm;
+    gint        notes_enc_hashing;
+    gint        notes_comp_algorithm;
+    gint        notes_comp_ratio;
+    gchar       notes_editor_font[MAXFONTNAME];
 };
 
 extern  struct osmo_prefs     config;
 
-gchar*  prefs_get_config_filename (gchar *config_filename);
-void    prefs_read_config       (void);
-void    prefs_write_config      (void);
+gchar*  prefs_get_config_filename   (gchar *config_filename);
+void    prefs_read_config           (void);
+void    prefs_write_config          (void);
 
 #endif /* _OPTIONS_PREFS_H */
 
