@@ -47,6 +47,7 @@ GtkStockItem calendar_stock_items[] = {
     { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_EXPORT,  (gchar*) N_("Export"),                      0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_IMPORT,  (gchar*) N_("Import"),                      0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_EDIT,             (gchar*) N_("Edit"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_BUTTON_INFO,             (gchar*) N_("Info"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_INSERT_TIMELINE,  (gchar*) N_("Insert"),                      0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_NEXT_YEAR,        (gchar*) N_("Next year"),                   0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_NO,               (gchar*) N_("No"),                          0, 0, TRANSLATION_DOMAIN },
@@ -66,6 +67,7 @@ GtkStockItem calendar_stock_items[] = {
 
     { (gchar*) OSMO_STOCK_ABOUT,                   (gchar*) N_("About"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALENDAR,                (gchar*) N_("Calendar"),                    0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_CLOSE,                   (gchar*) N_("Close"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALCULATOR,              (gchar*) N_("Calculator"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_ADD,            (gchar*) N_("Add contact"),                 0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_BIRTHDAYS,      (gchar*) N_("Show birthdays"),              0, 0, TRANSLATION_DOMAIN },
@@ -75,13 +77,27 @@ GtkStockItem calendar_stock_items[] = {
     { (gchar*) OSMO_STOCK_CONTACTS_REMOVE,         (gchar*) N_("Remove contact"),              0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS,                (gchar*) N_("Contacts"),                    0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDIT_NOTE,               (gchar*) N_("Edit day note"),               0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_BOLD,             (gchar*) N_("Bold"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_CLEAR,            (gchar*) N_("Clear"),                       0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_FIND,             (gchar*) N_("Find"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_HIGHLIGHT,        (gchar*) N_("Highlight"),                   0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_ITALIC,           (gchar*) N_("Italic"),                      0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_SAVE,             (gchar*) N_("Save"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_STRIKETHROUGH,    (gchar*) N_("Strikethrough"),               0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_UNDERLINE,        (gchar*) N_("Underline"),                   0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_FULLYEAR,                (gchar*) N_("Display full-year calendar"),  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_HELP,                    (gchar*) N_("Help"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_JUMPTO,                  (gchar*) N_("Jump to date"),                0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_LICENSE,                 (gchar*) N_("License"),                     0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_LIST_INVALID,            (gchar*) N_("Invalid item"),                0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_LIST_VALID,              (gchar*) N_("Valid item"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_NEXT_DAY,                (gchar*) N_("Next day"),                    0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_NEXT_MONTH,              (gchar*) N_("Next month"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_NEXT_YEAR,               (gchar*) N_("Next year"),                   0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES_ADD,               (gchar*) N_("Add note"),                    0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES_EDIT,              (gchar*) N_("Edit note"),                   0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES_REMOVE,            (gchar*) N_("Remove note"),                 0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES,                   (gchar*) N_("Notes"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_PREFERENCES,             (gchar*) N_("Preferences"),                 0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_PREV_DAY,                (gchar*) N_("Previous day"),                0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_PREV_MONTH,              (gchar*) N_("Previous month"),              0, 0, TRANSLATION_DOMAIN },
@@ -103,6 +119,7 @@ const guint8* calendar_stock_item_data[] = {
     (const guint8*) osmo_stock_button_contacts_export,
     (const guint8*) osmo_stock_button_contacts_import,
     (const guint8*) osmo_stock_button_edit,
+    (const guint8*) osmo_stock_button_info,
     (const guint8*) osmo_stock_button_insert_timeline,
     (const guint8*) osmo_stock_button_next_year,
     (const guint8*) osmo_stock_button_no,
@@ -122,6 +139,7 @@ const guint8* calendar_stock_item_data[] = {
 
     (const guint8*) osmo_stock_about,
     (const guint8*) osmo_stock_calendar,
+    (const guint8*) osmo_stock_close,
     (const guint8*) osmo_stock_calculator,
     (const guint8*) osmo_stock_contacts_add,
     (const guint8*) osmo_stock_contacts_birthdays,
@@ -131,13 +149,27 @@ const guint8* calendar_stock_item_data[] = {
     (const guint8*) osmo_stock_contacts_remove,
     (const guint8*) osmo_stock_contacts,
     (const guint8*) osmo_stock_edit_note,
+    (const guint8*) osmo_stock_editor_bold,
+    (const guint8*) osmo_stock_editor_clear,
+    (const guint8*) osmo_stock_editor_find,
+    (const guint8*) osmo_stock_editor_highlight,
+    (const guint8*) osmo_stock_editor_italic,
+    (const guint8*) osmo_stock_editor_save,
+    (const guint8*) osmo_stock_editor_strikethrough,
+    (const guint8*) osmo_stock_editor_underline,
     (const guint8*) osmo_stock_fullyear,
     (const guint8*) osmo_stock_help,
     (const guint8*) osmo_stock_jumpto,
     (const guint8*) osmo_stock_license,
+    (const guint8*) osmo_stock_list_invalid,
+    (const guint8*) osmo_stock_list_valid,
     (const guint8*) osmo_stock_next_day,
     (const guint8*) osmo_stock_next_month,
     (const guint8*) osmo_stock_next_year,
+    (const guint8*) osmo_stock_notes_add,
+    (const guint8*) osmo_stock_notes_edit,
+    (const guint8*) osmo_stock_notes_remove,
+    (const guint8*) osmo_stock_notes,
     (const guint8*) osmo_stock_preferences,
     (const guint8*) osmo_stock_prev_day,
     (const guint8*) osmo_stock_prev_month,
