@@ -32,6 +32,7 @@
 #define     OSMO_STOCK_BUTTON_CONTACTS_EXPORT   "osmo-button-contacts-export"
 #define     OSMO_STOCK_BUTTON_CONTACTS_IMPORT   "osmo-button-contacts-import"
 #define     OSMO_STOCK_BUTTON_EDIT              "osmo-button-edit"
+#define     OSMO_STOCK_BUTTON_INFO              "osmo-button-info"
 #define     OSMO_STOCK_BUTTON_INSERT_TIMELINE   "osmo-button-insert_timeline"
 #define     OSMO_STOCK_BUTTON_NEXT_YEAR         "osmo-button-next_year"
 #define     OSMO_STOCK_BUTTON_NO                "osmo-button-no"
@@ -51,6 +52,7 @@
 
 #define     OSMO_STOCK_ABOUT                    "osmo-about"
 #define     OSMO_STOCK_CALENDAR                 "osmo-calendar"
+#define     OSMO_STOCK_CLOSE                    "osmo-close"
 #define     OSMO_STOCK_CALCULATOR               "osmo-calculator"
 #define     OSMO_STOCK_CONTACTS_ADD             "osmo-contacts-add"
 #define     OSMO_STOCK_CONTACTS_BIRTHDAYS       "osmo-contacts-birthdays"
@@ -60,13 +62,27 @@
 #define     OSMO_STOCK_CONTACTS_REMOVE          "osmo-contacts-remove"
 #define     OSMO_STOCK_CONTACTS                 "osmo-contacts"
 #define     OSMO_STOCK_EDIT_NOTE                "osmo-edit_note"
+#define     OSMO_STOCK_EDITOR_BOLD              "osmo-editor-bold"
+#define     OSMO_STOCK_EDITOR_CLEAR             "osmo-editor-clear"
+#define     OSMO_STOCK_EDITOR_FIND              "osmo-editor-find"
+#define     OSMO_STOCK_EDITOR_HIGHLIGHT         "osmo-editor-highlight"
+#define     OSMO_STOCK_EDITOR_ITALIC            "osmo-editor-italic"
+#define     OSMO_STOCK_EDITOR_SAVE              "osmo-editor-save"
+#define     OSMO_STOCK_EDITOR_STRIKETHROUGH     "osmo-editor-strikethrough"
+#define     OSMO_STOCK_EDITOR_UNDERLINE         "osmo-editor-underline"
 #define     OSMO_STOCK_FULLYEAR                 "osmo-fullyear"
 #define     OSMO_STOCK_HELP                     "osmo-help"
 #define     OSMO_STOCK_JUMPTO                   "osmo-jumpto"
 #define     OSMO_STOCK_LICENSE                  "osmo-license"
+#define     OSMO_STOCK_LIST_INVALID             "osmo-list-invalid"
+#define     OSMO_STOCK_LIST_VALID               "osmo-list-valid"
 #define     OSMO_STOCK_NEXT_DAY                 "osmo-next-day"
 #define     OSMO_STOCK_NEXT_MONTH               "osmo-next-month"
 #define     OSMO_STOCK_NEXT_YEAR                "osmo-next-year"
+#define     OSMO_STOCK_NOTES_ADD                "osmo-notes-add"
+#define     OSMO_STOCK_NOTES_EDIT               "osmo-notes-edit"
+#define     OSMO_STOCK_NOTES_REMOVE             "osmo-notes-remove"
+#define     OSMO_STOCK_NOTES                    "osmo-notes"
 #define     OSMO_STOCK_PREFERENCES              "osmo-preferences"
 #define     OSMO_STOCK_PREV_DAY                 "osmo-prev-day"
 #define     OSMO_STOCK_PREV_MONTH               "osmo-prev-month"
