@@ -42,48 +42,6 @@
 
 /*------------------------------------------------------------------------------*/
 
-gint
-get_combobox_items (GtkComboBox *combo_box) {
-
-    return gtk_tree_model_iter_n_children (gtk_combo_box_get_model (GTK_COMBO_BOX (combo_box)), NULL);
-}
-
-/*------------------------------------------------------------------------------*/
-
-void
-create_category_combobox (GtkComboBox *combo_box, GtkListStore *store, gboolean none) {
-
-GtkTreeIter iter;
-gchar *category;
-gint i, n;
-
-    n = get_combobox_items(combo_box);
-
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), -1);
-
-    for (i = n-1; i >= 0; i--) {
-        gtk_combo_box_remove_text (GTK_COMBO_BOX (combo_box), i);
-    }
-
-    if (none == TRUE) {
-        gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("None"));
-    } else {
-        gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("All items"));
-    }
-
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(store), &iter, NULL, i++)) {
-
-        gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &category, -1);
-        gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), category);
-        g_free(category);
-    }
-
-}
-
-/*------------------------------------------------------------------------------*/
-
 gint
 get_priority_index (gchar *text) {
 
@@ -172,7 +130,7 @@ GtkTreeModel *model;
 /*------------------------------------------------------------------------------*/
 
 void
-fill_fields (GtkWidget *due_date_entry, GtkWidget *summary_entry, GtkWidget *desc_entry, GUI *appGUI) {
+tasks_fill_fields (GtkWidget *due_date_entry, GtkWidget *summary_entry, GtkWidget *desc_entry, GUI *appGUI) {
 
 GtkTreeIter iter;
 GtkTextIter titer;
@@ -199,12 +157,12 @@ GtkTextBuffer *text_buffer;
                 gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path);
 
                 gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
-                           COLUMN_DUE_DATE, &fduedate, 
-                           COLUMN_DUE_DATE_JULIAN, &appGUI->tsk->tasks_due_julian_day, 
-                           COLUMN_PRIORITY, &fpriority,
-                           COLUMN_CATEGORY, &fcategory,
-                           COLUMN_SUMMARY, &fsummary, 
-                           COLUMN_DESCRIPTION, &fdesc, -1);
+                           TA_COLUMN_DUE_DATE, &fduedate, 
+                           TA_COLUMN_DUE_DATE_JULIAN, &appGUI->tsk->tasks_due_julian_day, 
+                           TA_COLUMN_PRIORITY, &fpriority,
+                           TA_COLUMN_CATEGORY, &fcategory,
+                           TA_COLUMN_SUMMARY, &fsummary, 
+                           TA_COLUMN_DESCRIPTION, &fdesc, -1);
 
                 gtk_entry_set_text(GTK_ENTRY(due_date_entry), fduedate);
                 g_free(fduedate);
@@ -272,8 +230,8 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), TRUE);
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), TRUE);
 
-        gtk_tree_model_get (model, &iter, COLUMN_DESCRIPTION, &text,
-                            COLUMN_START_DATE_JULIAN, &start_date_julian, -1);  
+        gtk_tree_model_get (model, &iter, TA_COLUMN_DESCRIPTION, &text,
+                            TA_COLUMN_START_DATE_JULIAN, &start_date_julian, -1);  
 
         sprintf(tmpbuf, "\n%s: %s\n", _("Started"), julian_to_str(start_date_julian, DATE_FULL));
 
@@ -338,7 +296,6 @@ tasks_remove_item_cb (GtkWidget *widget, gpointer data) {
 void
 done_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data) {
 
-/*GtkTreeModel *model = (GtkTreeModel *)data;*/
 GtkTreePath *sort_path, *filter_path, *path;
 GtkTreeIter  iter;
 gboolean done_status;
@@ -359,8 +316,8 @@ GtkTreeModel *model;
 
             if (path != NULL) {
                 gtk_tree_model_get_iter (model, &iter, path);   /* get toggled iter */
-                gtk_tree_model_get (model, &iter, COLUMN_DONE, &done_status, -1);
-                gtk_list_store_set (GTK_LIST_STORE(model), &iter, COLUMN_DONE, !done_status, -1);
+                gtk_tree_model_get (model, &iter, TA_COLUMN_DONE, &done_status, -1);
+                gtk_list_store_set (GTK_LIST_STORE(model), &iter, TA_COLUMN_DONE, !done_status, -1);
 
                 if (done_status == TRUE && config.delete_completed) {
                     gtk_list_store_remove(GTK_LIST_STORE (model), &iter);
@@ -373,7 +330,8 @@ GtkTreeModel *model;
         gtk_tree_path_free (sort_path);
     }
 
-    apply_date_colors(appGUI);
+    apply_task_attributes (appGUI);
+    set_day_info (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -387,7 +345,7 @@ gint32 r;
 
     strncpy(due_date_color, "black", MAXCOLORNAME-1);
 
-    if (julian_day != 0) {
+    if (julian_day != 0 && done == FALSE) {
 
         julian_day_current = get_julian_for_today();
         r = julian_day - julian_day_current;
@@ -400,7 +358,7 @@ gint32 r;
 
             strncpy(due_date_color, config.due_7days_color, MAXCOLORNAME-1);
 
-        } else if (r < 0 && done == FALSE) {
+        } else if (r < 0) {
 
             strncpy(due_date_color, config.past_due_color, MAXCOLORNAME-1);
         }
@@ -412,19 +370,33 @@ gint32 r;
 /*------------------------------------------------------------------------------*/
 
 void
-apply_date_colors(GUI *appGUI) {
+apply_task_attributes (GUI *appGUI) {
 
 GtkTreeIter iter;
 gint i;
 gboolean done;
+gchar *priority;
 guint32 julian_day;
 
     i = 0;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
 
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, COLUMN_DONE, &done, COLUMN_DUE_DATE_JULIAN, &julian_day, -1);
-        gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, COLUMN_COLOR, get_date_color(julian_day, done), -1);
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
+                           TA_COLUMN_DONE, &done, TA_COLUMN_DUE_DATE_JULIAN, &julian_day, 
+                           TA_COLUMN_PRIORITY, &priority, -1);
+
+        if (get_priority_index (priority) == 2 && config.tasks_high_in_bold == TRUE) {    /* high priority ? */
+            gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, 
+                               TA_COLUMN_COLOR, get_date_color(julian_day, done), 
+                               TA_COLUMN_BOLD, PANGO_WEIGHT_BOLD,-1);
+        } else {
+            gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, 
+                               TA_COLUMN_COLOR, get_date_color(julian_day, done), 
+                               TA_COLUMN_BOLD, PANGO_WEIGHT_NORMAL,-1);
+        }
+
+        g_free (priority);
     }
 }
 
@@ -441,8 +413,8 @@ guint32 julian_day;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
 
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, COLUMN_DUE_DATE_JULIAN, &julian_day, -1);
-        gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, COLUMN_DUE_DATE, julian_to_str(julian_day, config.date_format), -1);
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, TA_COLUMN_DUE_DATE_JULIAN, &julian_day, -1);
+        gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_DUE_DATE, julian_to_str(julian_day, config.date_format), -1);
     }
 
 }
@@ -450,7 +422,7 @@ guint32 julian_day;
 /*------------------------------------------------------------------------------*/
 
 void
-update_n_items(GUI *appGUI) {
+update_tasks_number (GUI *appGUI) {
 
 GtkTreeIter iter;
 gint i;
@@ -482,16 +454,16 @@ GtkTreeIter iter;
     gtk_list_store_append(appGUI->tsk->tasks_list_store, &iter);
 
     if (due_date_julian == 0) {   /* use 'No date' text when due date is 0 */
-        gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, COLUMN_DONE, done, COLUMN_DUE_DATE, _("No date"), 
-                           COLUMN_START_DATE_JULIAN, start_date_julian, COLUMN_PRIORITY, priority, 
-                           COLUMN_CATEGORY, category, COLUMN_SUMMARY, summary, COLUMN_DESCRIPTION, desc, 
-                           COLUMN_COLOR, get_date_color(due_date_julian, done), -1);
+        gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_DONE, done, TA_COLUMN_DUE_DATE, _("No date"), 
+                           TA_COLUMN_START_DATE_JULIAN, start_date_julian, TA_COLUMN_PRIORITY, priority, 
+                           TA_COLUMN_CATEGORY, category, TA_COLUMN_SUMMARY, summary, TA_COLUMN_DESCRIPTION, desc, 
+                           TA_COLUMN_COLOR, get_date_color(due_date_julian, done), -1);
     } else {
-        gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, COLUMN_DONE, done, COLUMN_DUE_DATE, julian_to_str(due_date_julian, config.date_format),
-                           COLUMN_DUE_DATE_JULIAN, due_date_julian,
-                           COLUMN_START_DATE_JULIAN, start_date_julian, COLUMN_PRIORITY, priority, 
-                           COLUMN_CATEGORY, category, COLUMN_SUMMARY, summary, COLUMN_DESCRIPTION, desc,
-                           COLUMN_COLOR, get_date_color(due_date_julian, done), -1);
+        gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_DONE, done, TA_COLUMN_DUE_DATE, julian_to_str(due_date_julian, config.date_format),
+                           TA_COLUMN_DUE_DATE_JULIAN, due_date_julian,
+                           TA_COLUMN_START_DATE_JULIAN, start_date_julian, TA_COLUMN_PRIORITY, priority, 
+                           TA_COLUMN_CATEGORY, category, TA_COLUMN_SUMMARY, summary, TA_COLUMN_DESCRIPTION, desc,
+                           TA_COLUMN_COLOR, get_date_color(due_date_julian, done), -1);
     }
 }
 
@@ -528,25 +500,30 @@ gchar *category;
     if (appGUI->tsk->tasks_filter_disabled == TRUE)
         return TRUE;
 
-    gtk_tree_model_get(model, iter, COLUMN_DONE, &done, COLUMN_CATEGORY, &category, -1);
+    gtk_tree_model_get(model, iter, TA_COLUMN_DONE, &done, TA_COLUMN_CATEGORY, &category, -1);
 
     if(appGUI->tsk->filter_index) {
 
         if (gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category) == appGUI->tsk->filter_index) {
 
             if(config.hide_completed && done == TRUE) {
+                g_free (category);
                 return FALSE;
             }
+            g_free (category);
             return TRUE;
 
         } else {
+            g_free (category);
             return FALSE;
         }
 
     } else if (config.hide_completed && done == TRUE) {
+            g_free (category);
             return FALSE;
     }
 
+    g_free (category);
     return TRUE;
 }
 
@@ -561,7 +538,7 @@ category_filter_cb (GtkComboBox *widget, gpointer user_data) {
 
     if (appGUI->tsk->filter_index != -1) {
         gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter));
-        update_n_items(appGUI);
+        update_tasks_number (appGUI);
     }
 }
 
@@ -581,10 +558,10 @@ guint32 due_date_s, due_date_si;
         return 0;
     }
 
-    gtk_tree_model_get(model, iter_a, COLUMN_DONE, &done_a, 
-                       COLUMN_DUE_DATE_JULIAN, &due_date_a, COLUMN_PRIORITY, &priority_a, -1);
-    gtk_tree_model_get(model, iter_b, COLUMN_DONE, &done_b, 
-                       COLUMN_DUE_DATE_JULIAN, &due_date_b, COLUMN_PRIORITY, &priority_b, -1);
+    gtk_tree_model_get(model, iter_a, TA_COLUMN_DONE, &done_a, 
+                       TA_COLUMN_DUE_DATE_JULIAN, &due_date_a, TA_COLUMN_PRIORITY, &priority_a, -1);
+    gtk_tree_model_get(model, iter_b, TA_COLUMN_DONE, &done_b, 
+                       TA_COLUMN_DUE_DATE_JULIAN, &due_date_b, TA_COLUMN_PRIORITY, &priority_b, -1);
 
     done_s = done_a - done_b;
     done_si = done_b - done_a;
@@ -756,17 +733,18 @@ guint n_entries = G_N_ELEMENTS (entries);
 
     appGUI->tsk->filter_index = 0;
 
-    label = gtk_label_new(NULL);
-    gtk_label_set_angle (GTK_LABEL(label), -90.0);
-    sprintf(tmpbuf, "<b>%s</b>", _("Tasks"));
-    gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
-
     vbox1 = gtk_vbox_new (FALSE, 1);
     gtk_widget_show (vbox1);
     gtk_container_set_border_width (GTK_CONTAINER (vbox1), 8);
-    gtk_notebook_append_page(GTK_NOTEBOOK(appGUI->notebook), vbox1, label);
+    sprintf(tmpbuf, "<b>%s</b>", _("Tasks"));
+    gui_add_to_notebook (vbox1, tmpbuf, appGUI);
+
     appGUI->tsk->vbox = GTK_BOX(vbox1);
 
+    if (config.hide_tasks == TRUE) {
+        gtk_widget_hide(GTK_WIDGET(appGUI->tsk->vbox));
+    }
+
     /*-------------------------------------------------------------------------------------*/
 
     action_group = gtk_action_group_new ("_actions");
@@ -865,7 +843,7 @@ guint n_entries = G_N_ELEMENTS (entries);
     appGUI->tsk->tasks_list_store = gtk_list_store_new(TASKS_NUM_COLUMNS, 
                                          G_TYPE_BOOLEAN,
                                          G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING,
-                                         G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+                                         G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
 
     appGUI->tsk->tasks_filter = gtk_tree_model_filter_new(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), NULL);
     gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter), 
@@ -893,91 +871,105 @@ guint n_entries = G_N_ELEMENTS (entries);
     /* create columns */
 
     renderer = gtk_cell_renderer_toggle_new();
-    appGUI->tsk->tasks_columns[COLUMN_DONE] = gtk_tree_view_column_new_with_attributes (_("Done"),
+    appGUI->tsk->tasks_columns[TA_COLUMN_DONE] = gtk_tree_view_column_new_with_attributes (_("Done"),
                              renderer,
-                             "active", COLUMN_DONE,
+                             "active", TA_COLUMN_DONE,
                              NULL);
-    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_DONE]);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DONE]);
 
     g_signal_connect (renderer, "toggled", G_CALLBACK (done_toggled), appGUI);
 
     renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[COLUMN_DUE_DATE] = gtk_tree_view_column_new_with_attributes(_("Due date"),
+    appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE] = gtk_tree_view_column_new_with_attributes(_("Due date"),
                               renderer,
-                              "text", COLUMN_DUE_DATE,
-                              "strikethrough", COLUMN_DONE,
-                              "foreground", COLUMN_COLOR,
+                              "text", TA_COLUMN_DUE_DATE,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_DUE_DATE], config.visible_due_date_column);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_DUE_DATE]);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], config.visible_due_date_column);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE]);
 
     renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[COLUMN_DUE_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
+    appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
                               renderer,
-                              "text", COLUMN_DUE_DATE_JULIAN,
-                              "strikethrough", COLUMN_DONE,
-                              "foreground", COLUMN_COLOR,
+                              "text", TA_COLUMN_DUE_DATE_JULIAN,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_DUE_DATE_JULIAN], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_DUE_DATE_JULIAN]);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE_JULIAN], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE_JULIAN]);
 
     renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[COLUMN_START_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
+    appGUI->tsk->tasks_columns[TA_COLUMN_START_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
                               renderer,
-                              "text", COLUMN_START_DATE_JULIAN,
-                              "strikethrough", COLUMN_DONE,
-                              "foreground", COLUMN_COLOR,
+                              "text", TA_COLUMN_START_DATE_JULIAN,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_START_DATE_JULIAN], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_START_DATE_JULIAN]);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_START_DATE_JULIAN], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_START_DATE_JULIAN]);
 
     renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[COLUMN_PRIORITY] = gtk_tree_view_column_new_with_attributes(_("Priority"),
+    appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY] = gtk_tree_view_column_new_with_attributes(_("Priority"),
                               renderer,
-                              "text", COLUMN_PRIORITY,
-                              "strikethrough", COLUMN_DONE,
-                              "foreground", COLUMN_COLOR,
+                              "text", TA_COLUMN_PRIORITY,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_PRIORITY], config.visible_priority_column);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_PRIORITY]);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], config.visible_priority_column);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY]);
 
     renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[COLUMN_CATEGORY] = gtk_tree_view_column_new_with_attributes(_("Category"),
+    appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY] = gtk_tree_view_column_new_with_attributes(_("Category"),
                               renderer,
-                              "text", COLUMN_CATEGORY,
-                              "strikethrough", COLUMN_DONE,
-                              "foreground", COLUMN_COLOR,
+                              "text", TA_COLUMN_CATEGORY,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_CATEGORY], config.visible_category_column);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_CATEGORY]);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], config.visible_category_column);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY]);
 
     renderer = gtk_cell_renderer_text_new();
     g_object_set(G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
     gtk_cell_renderer_set_fixed_size(renderer, 0, -1);
-    appGUI->tsk->tasks_columns[COLUMN_SUMMARY] = gtk_tree_view_column_new_with_attributes(_("Summary"),
+    appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY] = gtk_tree_view_column_new_with_attributes(_("Summary"),
                               renderer,
-                              "text", COLUMN_SUMMARY,
-                              "strikethrough", COLUMN_DONE,
-                              "foreground", COLUMN_COLOR,
+                              "text", TA_COLUMN_SUMMARY,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_SUMMARY]);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]);
 
 
     renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[COLUMN_DESCRIPTION] = gtk_tree_view_column_new_with_attributes(_("Description"),
+    appGUI->tsk->tasks_columns[TA_COLUMN_DESCRIPTION] = gtk_tree_view_column_new_with_attributes(_("Description"),
                               renderer,
-                              "text", COLUMN_DESCRIPTION,
+                              "text", TA_COLUMN_DESCRIPTION,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_DESCRIPTION], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_DESCRIPTION]);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DESCRIPTION], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DESCRIPTION]);
 
     renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[COLUMN_COLOR] = gtk_tree_view_column_new_with_attributes(NULL,
+    appGUI->tsk->tasks_columns[TA_COLUMN_COLOR] = gtk_tree_view_column_new_with_attributes(NULL,
                               renderer,
-                              "text", COLUMN_COLOR,
+                              "text", TA_COLUMN_COLOR,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[COLUMN_COLOR], FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_COLOR]);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_COLOR], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_COLOR]);
+
+    renderer = gtk_cell_renderer_text_new();
+    appGUI->tsk->tasks_columns[TA_COLUMN_BOLD] = gtk_tree_view_column_new_with_attributes(NULL,
+                              renderer,
+                              "text", TA_COLUMN_BOLD,
+                              NULL);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_BOLD], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_BOLD]);
 
     /* configure list options */
 
@@ -989,9 +981,9 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_sortable_set_sort_func((GtkTreeSortable *)appGUI->tsk->tasks_sort, 0, 
                                     (GtkTreeIterCompareFunc)custom_tasks_sort_function, NULL, NULL);
 
-    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, COLUMN_DUE_DATE, config.tasks_sorting_order);
-    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, COLUMN_PRIORITY, config.tasks_sorting_order);
-    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, COLUMN_DONE, config.tasks_sorting_order);
+    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, TA_COLUMN_DUE_DATE, config.tasks_sorting_order);
+    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, TA_COLUMN_PRIORITY, config.tasks_sorting_order);
+    gtk_tree_sortable_set_sort_column_id((GtkTreeSortable *)appGUI->tsk->tasks_sort, TA_COLUMN_DONE, config.tasks_sorting_order);
 
     /*----------------------------------------------------------------------------*/
 
