@@ -70,7 +70,7 @@ guint32 fstartdate;
                 if (path != NULL) {
                     gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path);
                     gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
-                               COLUMN_START_DATE_JULIAN, &fstartdate, -1);
+                               TA_COLUMN_START_DATE_JULIAN, &fstartdate, -1);
                     gtk_list_store_remove(appGUI->tsk->tasks_list_store, &iter);
                     gtk_tree_path_free(path);
                 }
@@ -109,10 +109,11 @@ guint32 fstartdate;
                         gui_systray_tooltip_update(appGUI);
     }
 
-    gtk_widget_destroy(appGUI->tsk->tasks_add_window);
-    update_n_items(appGUI);
-    tasks_select_first_position_in_list(appGUI);
-    g_signal_emit_by_name(G_OBJECT(appGUI->cal->calendar), "day-selected");
+    gtk_widget_destroy (appGUI->tsk->tasks_add_window);
+    update_tasks_number (appGUI);
+    tasks_select_first_position_in_list (appGUI);
+    g_signal_emit_by_name (G_OBJECT(appGUI->cal->calendar), "day-selected");
+    apply_task_attributes (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -153,23 +154,53 @@ button_close_calendar_cb (GtkButton *button, gpointer user_data) {
 /*------------------------------------------------------------------------------*/
 
 void
-set_today_calendar_cb (GtkWidget *widget, gpointer data) {
-
-struct tm   *timer;
-time_t      tmm;
+button_ok_calendar_cb (GtkButton *button, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
-
-    tmm = time(NULL); 
-    timer = localtime(&tmm);
-
-    gui_calendar_select_month (GUI_CALENDAR(appGUI->tsk->td_calendar), timer->tm_mon, timer->tm_year + 1900);
-    gui_calendar_select_day (GUI_CALENDAR(appGUI->tsk->td_calendar), timer->tm_mday);
     day_selected_cb (GUI_CALENDAR(appGUI->tsk->td_calendar), appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
 
+void
+set_today_calendar_cb (GtkWidget *widget, gpointer data) {
+
+GUI *appGUI = (GUI *)data;
+
+    gui_calendar_select_month (GUI_CALENDAR (appGUI->tsk->td_calendar), get_current_month(), get_current_year());
+    gui_calendar_select_day (GUI_CALENDAR (appGUI->tsk->td_calendar), get_current_day());
+    day_selected_cb (GUI_CALENDAR (appGUI->tsk->td_calendar), appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+set_tomorrow_calendar_cb (GtkWidget *widget, gpointer data) {
+
+GUI *appGUI = (GUI *)data;
+int year, month, day;
+
+    year = get_current_year();
+    month = get_current_month();
+    day = get_current_day() + 1;
+
+    if (day > get_number_of_days_in_month (month, year)) {
+        month++;
+        day = 1;
+
+        if (month > 11) {
+            year++;
+            month = 0;
+        }
+    } 
+
+    gui_calendar_select_month (GUI_CALENDAR (appGUI->tsk->td_calendar), month, year);
+    gui_calendar_select_day (GUI_CALENDAR (appGUI->tsk->td_calendar), day);
+    day_selected_cb (GUI_CALENDAR (appGUI->tsk->td_calendar), appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 nodate_calendar_cb (GtkWidget *widget, gpointer data) {
 
@@ -204,16 +235,18 @@ GtkWidget *vbox1;
 GtkWidget *hbox1;
 GtkWidget *alignment;
 GtkWidget *today_button;
+GtkWidget *tomorrow_button;
 GtkWidget *nodate_button;
 GtkWidget *close_button;
+GtkWidget *ok_button;
 
     GUI *appGUI = (GUI *)data;
 
-    appGUI->tsk->td_calendar_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_position(GTK_WINDOW(appGUI->tsk->td_calendar_window), GTK_WIN_POS_MOUSE);
-    gtk_window_set_modal(GTK_WINDOW(appGUI->tsk->td_calendar_window), TRUE);
-    gtk_window_set_transient_for(GTK_WINDOW(appGUI->tsk->td_calendar_window), GTK_WINDOW(appGUI->tsk->tasks_add_window));
-    gtk_window_set_decorated(GTK_WINDOW(appGUI->tsk->td_calendar_window), FALSE);
+    appGUI->tsk->td_calendar_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    gtk_window_set_position (GTK_WINDOW (appGUI->tsk->td_calendar_window), GTK_WIN_POS_MOUSE);
+    gtk_window_set_modal (GTK_WINDOW (appGUI->tsk->td_calendar_window), TRUE);
+    gtk_window_set_transient_for (GTK_WINDOW (appGUI->tsk->td_calendar_window), GTK_WINDOW (appGUI->tsk->tasks_add_window));
+    gtk_window_set_decorated (GTK_WINDOW (appGUI->tsk->td_calendar_window), FALSE);
     g_signal_connect (G_OBJECT (appGUI->tsk->td_calendar_window), "key_press_event",
                       G_CALLBACK (sd_key_press_cb), appGUI);
 
@@ -227,8 +260,8 @@ GtkWidget *close_button;
     gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
 
     appGUI->tsk->td_calendar = gui_calendar_new();
-    gui_calendar_set_cursor_type(GUI_CALENDAR(appGUI->tsk->td_calendar), CURSOR_BLOCK);
-    gtk_widget_show(appGUI->tsk->td_calendar);
+    gui_calendar_set_cursor_type (GUI_CALENDAR (appGUI->tsk->td_calendar), CURSOR_BLOCK);
+    gtk_widget_show (appGUI->tsk->td_calendar);
     g_signal_connect (GTK_OBJECT (appGUI->tsk->td_calendar), "day_selected_double_click",
                       G_CALLBACK (day_selected_cb), appGUI);
     gtk_container_add (GTK_CONTAINER (alignment), appGUI->tsk->td_calendar);
@@ -248,19 +281,37 @@ GtkWidget *close_button;
     g_signal_connect (G_OBJECT (today_button), "clicked",
                         G_CALLBACK (set_today_calendar_cb), appGUI);
 
+    tomorrow_button = gtk_button_new_with_mnemonic (_("Tomorrow"));
+    gtk_widget_show (tomorrow_button);
+    gtk_box_pack_start (GTK_BOX (hbox1), tomorrow_button, FALSE, FALSE, 0);
+    g_signal_connect (G_OBJECT (tomorrow_button), "clicked",
+                        G_CALLBACK (set_tomorrow_calendar_cb), appGUI);
+
     nodate_button = gtk_button_new_with_mnemonic (_("No date"));
     gtk_widget_show (nodate_button);
-    gtk_box_pack_start (GTK_BOX (hbox1), nodate_button, FALSE, FALSE, 4);
+    gtk_box_pack_start (GTK_BOX (hbox1), nodate_button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (nodate_button), "clicked",
                         G_CALLBACK (nodate_calendar_cb), appGUI);
 
     if (config.default_stock_icons) {
-        close_button = gui_stock_button(GTK_STOCK_CLOSE, FALSE);
+        ok_button = gui_stock_button (GTK_STOCK_OK, FALSE);
     } else {
-        close_button = gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
+        ok_button = gui_stock_button (OSMO_STOCK_BUTTON_OK, FALSE);
     }
-    GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
-    gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
+    GTK_WIDGET_UNSET_FLAGS (ok_button, GTK_CAN_FOCUS);
+    gtk_button_set_relief (GTK_BUTTON (ok_button), GTK_RELIEF_NONE);
+    gtk_widget_show (ok_button);
+    gtk_box_pack_end (GTK_BOX (hbox1), ok_button, FALSE, FALSE, 0);
+    g_signal_connect (G_OBJECT (ok_button), "clicked",
+                        G_CALLBACK (button_ok_calendar_cb), appGUI);
+
+    if (config.default_stock_icons) {
+        close_button = gui_stock_button (GTK_STOCK_CLOSE, FALSE);
+    } else {
+        close_button = gui_stock_button (OSMO_STOCK_BUTTON_CLOSE, FALSE);
+    }
+    GTK_WIDGET_UNSET_FLAGS (close_button, GTK_CAN_FOCUS);
+    gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
     gtk_widget_show (close_button);
     gtk_box_pack_end (GTK_BOX (hbox1), close_button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (close_button), "clicked",
@@ -269,7 +320,7 @@ GtkWidget *close_button;
     gtk_widget_show (appGUI->tsk->td_calendar_window);
 
     gui_calendar_set_display_options (GUI_CALENDAR (appGUI->tsk->td_calendar), 
-                                      GUI_CALENDAR_SHOW_HEADING | GUI_CALENDAR_SHOW_DAY_NAMES | GUI_CALENDAR_WEEK_START_MONDAY);
+                                      (config.display_options & !GUI_CALENDAR_NO_MONTH_CHANGE) | GUI_CALENDAR_SHOW_HEADING | GUI_CALENDAR_SHOW_DAY_NAMES);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -277,7 +328,7 @@ GtkWidget *close_button;
 void
 tasks_add_edit_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 
-    GUI *appGUI = (GUI *)user_data;
+GUI *appGUI = (GUI *)user_data;
 
     gtk_window_get_size (GTK_WINDOW(appGUI->tsk->tasks_add_window),
                         &config.tasks_addedit_win_w, &config.tasks_addedit_win_h);
@@ -299,7 +350,7 @@ button_tasks_add_edit_window_close_cb (GtkButton *button, gpointer user_data) {
 gint 
 tasks_add_edit_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
-    GUI *appGUI = (GUI *)data;
+GUI *appGUI = (GUI *)data;
 
     switch(event->keyval) {
 
@@ -308,13 +359,13 @@ tasks_add_edit_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer dat
             return TRUE;
     }
 
-    if(strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->tsk->summary_entry)))) {
+    if (strlen (gtk_entry_get_text (GTK_ENTRY (appGUI->tsk->summary_entry)))) {
         appGUI->tsk->tasks_accept_state = TRUE;
     } else {
         appGUI->tsk->tasks_accept_state = FALSE;
     }
 
-    gtk_widget_set_sensitive(appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
+    gtk_widget_set_sensitive (appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
 
     return FALSE;
 }
@@ -343,23 +394,23 @@ gchar tmpbuf[BUFFER_SIZE];
 
                 sprintf (tmpbuf, "%s\n\n%s", _("Selected task will be removed."), _("Are you sure?"));
 
-                response = gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
+                response = gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
 
                 if (response == GTK_RESPONSE_YES) {   
-                    gtk_tree_model_get_iter(GTK_TREE_MODEL(list_store), &iter, path);
-                    gtk_list_store_remove(list_store, &iter);
-                    gtk_tree_path_free(path);
-                    tasks_select_first_position_in_list(appGUI);
-                    update_n_items(appGUI);
-                    g_signal_emit_by_name(G_OBJECT(appGUI->cal->calendar), "day-selected");
-                    gui_systray_tooltip_update(appGUI);
+                    gtk_tree_model_get_iter (GTK_TREE_MODEL(list_store), &iter, path);
+                    gtk_list_store_remove (list_store, &iter);
+                    gtk_tree_path_free (path);
+                    tasks_select_first_position_in_list (appGUI);
+                    update_tasks_number (appGUI);
+                    g_signal_emit_by_name (G_OBJECT(appGUI->cal->calendar), "day-selected");
+                    gui_systray_tooltip_update (appGUI);
                 }
             }
 
-            gtk_tree_path_free(filter_path);
+            gtk_tree_path_free (filter_path);
         }
 
-        gtk_tree_path_free(sort_path);
+        gtk_tree_path_free (sort_path);
     }
 }
 
@@ -387,6 +438,7 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_window_set_title (GTK_WINDOW (appGUI->tsk->tasks_add_window), _("Edit task"));
     } else {
         gtk_window_set_title (GTK_WINDOW (appGUI->tsk->tasks_add_window), _("Add task"));
+        appGUI->tsk->tasks_due_julian_day = 0;
     }
 
     gtk_window_move (GTK_WINDOW (appGUI->tsk->tasks_add_window), 
@@ -481,7 +533,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_table_attach (GTK_TABLE (table), appGUI->tsk->category_combobox, 1, 2, 2, 3,
                      (GtkAttachOptions) (GTK_FILL),
                      (GtkAttachOptions) (0), 0, 0);
-    create_category_combobox (GTK_COMBO_BOX (appGUI->tsk->category_combobox), appGUI->opt->tasks_category_store, TRUE);
+    gui_create_category_combobox (GTK_COMBO_BOX (appGUI->tsk->category_combobox), appGUI->opt->tasks_category_store, TRUE);
     gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->tsk->category_combobox), 
             gui_list_store_get_text_index (appGUI->opt->tasks_category_store, gtk_combo_box_get_active_text(GTK_COMBO_BOX(appGUI->tsk->cf_combobox))));
 
@@ -570,7 +622,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
     if (tasks_edit_mode == TRUE) {
         appGUI->tsk->tasks_accept_state = TRUE;
-        fill_fields (appGUI->tsk->due_date_entry, appGUI->tsk->summary_entry, appGUI->tsk->desc_textview, appGUI);
+        tasks_fill_fields (appGUI->tsk->due_date_entry, appGUI->tsk->summary_entry, appGUI->tsk->desc_textview, appGUI);
     }
 
     gtk_widget_set_sensitive(appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
@@ -740,7 +792,7 @@ xmlNodePtr main_node, node, note_node;
 xmlAttrPtr attr;
 gchar temp[BUFFER_SIZE];
 GtkTreeIter iter;
-gboolean *done;
+gboolean done;
 gchar *priority, *category, *summary, *desc;
 guint32 due_date_julian, start_date_julian;
 
@@ -769,13 +821,13 @@ guint32 due_date_julian, start_date_julian;
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
 
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
-                           COLUMN_DONE, &done,
-                           COLUMN_DUE_DATE_JULIAN, &due_date_julian,
-                           COLUMN_START_DATE_JULIAN, &start_date_julian,
-                           COLUMN_PRIORITY, &priority,
-                           COLUMN_CATEGORY, &category,
-                           COLUMN_SUMMARY, &summary,
-                           COLUMN_DESCRIPTION, &desc, -1);
+                           TA_COLUMN_DONE, &done,
+                           TA_COLUMN_DUE_DATE_JULIAN, &due_date_julian,
+                           TA_COLUMN_START_DATE_JULIAN, &start_date_julian,
+                           TA_COLUMN_PRIORITY, &priority,
+                           TA_COLUMN_CATEGORY, &category,
+                           TA_COLUMN_SUMMARY, &summary,
+                           TA_COLUMN_DESCRIPTION, &desc, -1);
 
         note_node = xmlNewChild(node, NULL, (const xmlChar *) "entry", (xmlChar *) NULL);
         sprintf(temp, "%d", (gint) done);
@@ -786,9 +838,13 @@ guint32 due_date_julian, start_date_julian;
         xmlNewChild(note_node, NULL, (const xmlChar *) "start_date", (xmlChar *) temp);
         sprintf(temp, "%d", get_priority_index(gettext(priority)));
         xmlNewChild(note_node, NULL, (const xmlChar *) "priority", (xmlChar *) temp);
+        g_free (priority);
         xmlNewChild(note_node, NULL, (const xmlChar *) "category", (xmlChar *) category);
+        g_free (category);
         xmlNewChild(note_node, NULL, (const xmlChar *) "summary", (xmlChar *) summary);
+        g_free (summary);
         xmlNewChild(note_node, NULL, (const xmlChar *) "description", (xmlChar *) desc);
+        g_free (desc);
     }
 
     xmlSaveFormatFileEnc(prefs_get_config_filename(TASKS_ENTRIES_FILENAME), doc, "utf-8", 1);
