@@ -24,9 +24,6 @@
 
 #include "gui.h"
 
-#define TASKS_ADD_EDIT_WINDOW_SIZE_X    370
-#define TASKS_ADD_EDIT_WINDOW_SIZE_Y    440
-
 void    read_tasks_entries              (GUI *appGUI);
 void    write_tasks_entries             (GUI *appGUI);
 void    tasks_remove_dialog_show        (GtkWidget *list, GtkListStore *list_store, GUI *appGUI);
