@@ -159,7 +159,7 @@ is_valid_time2(gint hour, gint minute, gint second, gboolean mode24) {
 /*------------------------------------------------------------------------------*/
 
 gchar*
-time_to_str(gint time_format) {
+current_time_to_str(gint time_format) {
 
 static gchar buffer[BUFFER_SIZE];
 const struct tm *timer;
@@ -182,6 +182,32 @@ gchar *time_format_str[] = {
 
 /*------------------------------------------------------------------------------*/
 
+gchar*
+time_to_str(TIME *time, gint time_format) {
+
+static gchar buffer[BUFFER_SIZE];
+struct tm timer;
+
+gchar *time_format_str[] = {
+    "%R", "%I:%M %p", "%T", "%r", "%Z"
+};
+
+    timer.tm_hour = time->hour;
+    timer.tm_min = time->minute; 
+    timer.tm_sec = time->second;
+
+    strcpy(buffer, "empty");
+
+    if (time_format < TIME_HH_MM || time_format > TIME_TIMEZONE) {
+        time_format = TIME_HH_MM;
+    }
+    
+    strftime (buffer, BUFFER_SIZE-1, time_format_str[time_format], &timer);
+    return buffer;
+}
+
+/*------------------------------------------------------------------------------*/
+
 gboolean 
 time_handler (GUI *appGUI) {
 
@@ -191,9 +217,9 @@ gchar tmpbuf[BUFFER_SIZE];
     /* display current time in calendar day info */
 
     if (config.time_format == TIME_24) {
-        sprintf(tmpbuf, "<tt>%s</tt>", time_to_str(TIME_HH_MM_SS));
+        sprintf(tmpbuf, "<tt>%s</tt>", current_time_to_str(TIME_HH_MM_SS));
     } else {
-        sprintf(tmpbuf, "<tt>%s</tt>", time_to_str(TIME_HH_MM_SS_AMPM));
+        sprintf(tmpbuf, "<tt>%s</tt>", current_time_to_str(TIME_HH_MM_SS_AMPM));
     }
     gtk_label_set_markup (GTK_LABEL (appGUI->cal->time_label), tmpbuf);
 
